// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/base"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : CrossPlanTaskHeadDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : CrossPlanTaskHead的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
type CrossPlanTaskHeadDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewCrossPlanTaskHeadDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个CrossPlanTaskHeadDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : CrossPlanTaskHeadDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func NewCrossPlanTaskHeadDAOImplement(session *xorm.Session, userid string) *CrossPlanTaskHeadDAOImplement {
	return &CrossPlanTaskHeadDAOImplement{session, &meta.CrossPlanTaskHead, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.InsertOne
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) InsertOne(entity *model.CrossPlanTaskHead) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) DeleteOne(taskNr int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{taskNr}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.SelectOne
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) SelectOne(taskNr int) (*model.CrossPlanTaskHead, error) {
	var data model.CrossPlanTaskHead
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{taskNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) UpdateOne(entity *model.CrossPlanTaskHead) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.Insert
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) Insert(entities *[]model.CrossPlanTaskHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.Delete
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) Delete(entities *[]model.CrossPlanTaskHead) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.Select
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.CrossPlanTaskHead, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.CrossPlanTaskHead, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.SelectCols
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) SelectCols(predicates []grmi.Predicate, orderByFields []grmi.Field, cloumns []string) ([]map[string]interface{}, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]map[string]interface{}, 0, 10)
	err := session.Cols(cloumns...).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by "
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.CrossPlanTaskHead, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.Update
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) Update(entities *[]model.CrossPlanTaskHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.CrossPlanTaskHead, columns ...string) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.CrossPlanTaskHead_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/CrossPlanTaskHeadDAO.Update
 *
 ******************************************************************************/
func (impl *CrossPlanTaskHeadDAOImplement) SelectUnAccomplishTask(toPlantNr int) ([]model.CrossPlanTaskHead,  error) {
	where := fmt.Sprintf("%s = ? and %s = ?", meta.CrossPlanTaskHead_ToPlantNr.ColumnName, meta.CrossPlanTaskHead_Status.ColumnName)
	parameters := []interface{}{toPlantNr, model.CROSS_TASK_STATUS_PLAN}
	taskHeadLi := make([]model.CrossPlanTaskHead, 0)
	err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Desc(meta.CrossPlanTaskHead_Priority.Name).Asc(meta.CrossPlanTaskHead_TaskNr.Name).Find(&taskHeadLi)
	return taskHeadLi, err
}