// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/base"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : MaterialFrameInfoDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : MaterialFrameInfo的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
type MaterialFrameInfoDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewMaterialFrameInfoDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个MaterialFrameInfoDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : MaterialFrameInfoDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func NewMaterialFrameInfoDAOImplement(session *xorm.Session, plantNr int, userid string) *MaterialFrameInfoDAOImplement {
	return &MaterialFrameInfoDAOImplement{session, &meta.MaterialFrameInfo, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.InsertOne
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) InsertOne(entity *model.MaterialFrameInfo) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) DeleteOne(workPlaceNr int, workPlaceDesc string, gatewayIP string, lampAddress string, frameID int, levelID int, boxID int, tagAddr string, artID string, custArtID string, descCN string, standardPack int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workPlaceNr, workPlaceDesc, gatewayIP, lampAddress, frameID, levelID, boxID, tagAddr, artID, custArtID, descCN, standardPack}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.SelectOne
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) SelectOne(workPlaceNr int, workPlaceDesc string, gatewayIP string, lampAddress string, frameID int, levelID int, boxID int, tagAddr string, artID string, custArtID string, descCN string, standardPack int) (*model.MaterialFrameInfo, error) {
	var data model.MaterialFrameInfo
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workPlaceNr, workPlaceDesc, gatewayIP, lampAddress, frameID, levelID, boxID, tagAddr, artID, custArtID, descCN, standardPack}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) UpdateOne(entity *model.MaterialFrameInfo) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.Insert
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) Insert(entities *[]model.MaterialFrameInfo) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.Delete
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) Delete(entities *[]model.MaterialFrameInfo) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.MaterialFrameInfo_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.Select
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.MaterialFrameInfo, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.MaterialFrameInfo_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.MaterialFrameInfo_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.MaterialFrameInfo, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.MaterialFrameInfo_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.MaterialFrameInfo_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.MaterialFrameInfo, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.Update
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) Update(entities *[]model.MaterialFrameInfo) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.MaterialFrameInfo, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.MaterialFrameInfo_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.MaterialFrameInfo_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/MaterialFrameInfoDAO.UpdateInfo
 *
 ******************************************************************************/
func (impl *MaterialFrameInfoDAOImplement) UpdateInfo(workPlaceNr int, entity *model.MaterialFrameInfo) error {
	sql := fmt.Sprintf(`update %s set %s = ? , %s = ? , %s = ? where %s = ? and %s = ?`,
		meta.MaterialFrameInfo.TableName,
		meta.MaterialFrameInfo_LampAddress.ColumnName,
		meta.MaterialFrameInfo_GatewayIP.ColumnName,
		meta.MaterialFrameInfo_LastUser.ColumnName,
		meta.MaterialFrameInfo_PlantNr.ColumnName,
		meta.MaterialFrameInfo_WorkPlaceNr.ColumnName)
	_, err := impl.session.Table(impl.meta.TableName).Exec(sql, entity.LampAddress, entity.GatewayIP, impl.userid, impl.plantNr, workPlaceNr)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
