// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"fmt"
	"github.com/go-xorm/xorm"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/base"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : RPDashBoardHeadDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : RPDashBoardHead的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 14:56:42
 *
 ******************************************************************************/
type RPDashBoardHeadDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewRPDashBoardHeadDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个RPDashBoardHeadDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : RPDashBoardHeadDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 14:56:42
 *
 ******************************************************************************/
func NewRPDashBoardHeadDAOImplement(session *xorm.Session, plantNr int, userid string) *RPDashBoardHeadDAOImplement {
	return &RPDashBoardHeadDAOImplement{session, &meta.RPDashBoardHead, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.InsertOne
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) InsertOne(entity *model.RPDashBoardHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) DeleteOne(dashboardId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, dashboardId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.SelectOne
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) SelectOne(dashboardId string) (*model.RPDashBoardHead, error) {
	var data model.RPDashBoardHead
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, dashboardId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) UpdateOne(entity *model.RPDashBoardHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.Insert
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) Insert(entities *[]model.RPDashBoardHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.Delete
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) Delete(entities *[]model.RPDashBoardHead) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.RPDashBoardHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.Select
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.RPDashBoardHead, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.RPDashBoardHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.RPDashBoardHead_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.RPDashBoardHead, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.SelectCols
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) SelectCols(predicates []grmi.Predicate, orderByFields []grmi.Field, cloumns []string) ([]map[string]interface{}, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.RPDashBoardHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.RPDashBoardHead_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]map[string]interface{}, 0, 10)
	err := session.Cols(cloumns...).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.RPDashBoardHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.RPDashBoardHead_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.RPDashBoardHead, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.Update
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) Update(entities *[]model.RPDashBoardHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference leit.com/LAPP_ACURA_MOM_BACKEND/dao/base/RPDashBoardHeadDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *RPDashBoardHeadDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.RPDashBoardHead, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.RPDashBoardHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.RPDashBoardHead_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
