// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/base"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WorkLineProcessLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkLineProcessLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-22 17:33:27
 *
 ******************************************************************************/
type WorkLineProcessLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWorkLineProcessLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkLineProcessLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkLineProcessLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-22 17:33:27
 *
 ******************************************************************************/
func NewWorkLineProcessLstDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkLineProcessLstDAOImplement {
	return &WorkLineProcessLstDAOImplement{session, &meta.WorkLineProcessLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) InsertOne(entity *model.WorkLineProcessLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) DeleteOne(workLineId string, pO string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workLineId, pO}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) SelectOne(workLineId string, pO string) (*model.WorkLineProcessLst, error) {
	var data model.WorkLineProcessLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workLineId, pO}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) UpdateOne(entity *model.WorkLineProcessLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.Insert
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) Insert(entities *[]model.WorkLineProcessLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.Delete
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) Delete(entities *[]model.WorkLineProcessLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLineProcessLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.Select
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkLineProcessLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLineProcessLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WorkLineProcessLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkLineProcessLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.SelectCols
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) SelectCols(predicates []grmi.Predicate, orderByFields []grmi.Field, cloumns []string) ([]model.WorkLineProcessLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLineProcessLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WorkLineProcessLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkLineProcessLst, 0, 10)
	err := session.Cols(cloumns...).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLineProcessLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.WorkLineProcessLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkLineProcessLst, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.Update
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) Update(entities *[]model.WorkLineProcessLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WorkLineProcessLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLineProcessLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WorkLineProcessLst_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAOImplement.GetMaxPost
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) GetMaxPost(workLineId string) (int, error) {

	parameters := []interface{}{impl.plantNr, workLineId}
	where := fmt.Sprintf("%s = ? and %s = ?", meta.WorkLineProcessLst_PlantNr.ColumnName, meta.WorkLineProcessLst_WorkLineId.ColumnName)
	var data model.WorkLineProcessLst
	ok, err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Desc(meta.WorkLineProcessLst_Pos.SortColumnName).Get(&data)
	if err != nil {
		return 0, err
	}
	if !ok {
		return 0, nil
	}
	return data.Pos, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/WorkLineProcessLstDAOImplement.SelectProcessByWorkLine
 *
 ******************************************************************************/
func (impl *WorkLineProcessLstDAOImplement) SelectProcessByWorkLine(workLineId string) ([]model.Process, error) {
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.WorkLineProcessLst_PlantNr.ColumnName,
		meta.Process_PlantNr.ColumnName,
		meta.WorkLineProcessLst_PO.ColumnName,
		meta.Process_PO.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.Process.TableName, condition)
	parameters := []interface{}{impl.plantNr, workLineId}
	where := fmt.Sprintf("%s = ? and %s = ?", meta.WorkLineProcessLst_PlantNr.ColumnName, meta.WorkLineProcessLst_WorkLineId.ColumnName)
	result := make([]model.Process, 0, 10)
	err := session.Where(where, parameters...).OrderBy(meta.WorkLineProcessLst_Pos.ColumnName).Find(&result)
	return result, err
}