// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/jit"
	omMeta "LAPP_ACURA_MOM_BACKEND/meta/om"
	model "LAPP_ACURA_MOM_BACKEND/models/jit"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : PackOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : PackOrder的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
type PackOrderDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewPackOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PackOrderDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : PackOrderDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func NewPackOrderDAOImplement(session *xorm.Session, plantNr int, userid string) *PackOrderDAOImplement {
	return &PackOrderDAOImplement{session, &meta.PackOrder, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.InsertOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) InsertOne(entity *model.PackOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) DeleteOne(packOrderId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, packOrderId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.SelectOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectOne(packOrderId string) (*model.PackOrder, error) {
	var data model.PackOrder
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, packOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) UpdateOne(entity *model.PackOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.Insert
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) Insert(entities *[]model.PackOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.Delete
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) Delete(entities *[]model.PackOrder) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.PackOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.Select
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PackOrder, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.PackOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.PackOrder_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.PackOrder, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.PackOrder_PlantNr.ColumnName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderStatus_PlantNr.ColumnName,
		meta.PackOrder_PackOrderId.ColumnName,
		meta.PackOrderStatus_PackOrderId.ColumnName)
	joinStr := fmt.Sprintf(" left join %s on %s ", meta.PackOrderStatus.TableName, condition)
	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.PackOrder_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PackOrderWithStatus, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL(fmt.Sprintf("select %s.*,%s.* from [", meta.PackOrder.TableName, meta.PackOrderStatus.TableName)+impl.meta.TableName+"]"+joinStr+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	packOrderLi := make([]model.PackOrder, 0, len(data))
	for _, item := range data {
		packOrder := item.PackOrder
		packOrder.PackOrderStatus = item.PackOrderStatus
		packOrderLi = append(packOrderLi, packOrder)
	}
	return grmi.PagingResult{Records: packOrderLi, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.Update
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) Update(entities *[]model.PackOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.PackOrder, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.PackOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.PackOrder_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.SelectOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectOneWithStatus(packOrderId string) (*model.PackOrderWithStatus, error) {
	var data model.PackOrderWithStatus
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderStatus_PlantNr.ColumnName,
		meta.PackOrder_PackOrderId.ColumnName,
		meta.PackOrderStatus_PackOrderId.ColumnName)
	ok, err := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.PackOrderStatus.TableName, condition).
		Where(fmt.Sprintf("%s = ? and %s = ?", meta.PackOrder_PlantNr.ColumnName, meta.PackOrder_PackOrderId.ColumnName), impl.plantNr, packOrderId).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.SelectUserRunningPackOrder
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectUserRunningPackOrder(userId string, location string) ([]model.PackOrderWithStatus, error) {
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderStatus_PlantNr.ColumnName,
		meta.PackOrder_PackOrderId.ColumnName,
		meta.PackOrderStatus_PackOrderId.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.PackOrderStatus.TableName, condition)
	parameters := []interface{}{impl.plantNr, userId, location, model.PACK_STATUS_RUNNING}
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ? and %s = ?",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrder_Operator.ColumnName,
		meta.PackOrder_PackLocation.ColumnName,
		meta.PackOrderStatus_Status.ColumnName)
	data := make([]model.PackOrderWithStatus, 0, 10)
	err := session.Where(where, parameters...).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.SelectUserClosePackOrder
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectUserClosePackOrder(startDayTime string, endDayTime string, worklineIds []string) ([]model.PackOrder, error) {

	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderStatus_PlantNr.ColumnName,
		meta.PackOrder_PackOrderId.ColumnName,
		meta.PackOrderStatus_PackOrderId.ColumnName)

	condition1 := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderItemLst_PlantNr.ColumnName,
		meta.PackOrder_PackOrderId.ColumnName,
		meta.PackOrderItemLst_PackOrderId.ColumnName)

	condition2 := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderItemLst_PlantNr.ColumnName,
		omMeta.SerialOrder_SerialOrderId.ColumnName,
		meta.PackOrderItemLst_SerialOrderId.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.PackOrderStatus.TableName, condition).Join("LEFT", meta.PackOrderItemLst.TableName, condition1).Join("LEFT", omMeta.SerialOrder.TableName, condition2)
	parameters := []interface{}{impl.plantNr, startDayTime, endDayTime, model.PACK_TYPE_STD, model.PACK_STATUS_CLOSED}
	where := fmt.Sprintf("%s = ? and %s >= ? and %s < ? and %s = ? and %s = ?",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrder_CloseTime.ColumnName,
		meta.PackOrder_CloseTime.ColumnName,
		meta.PackOrder_PackTypeId.ColumnName,
		meta.PackOrderStatus_Status.ColumnName)
	data := make([]model.PackOrder, 0, 10)
	err := session.Where(where, parameters...).In(omMeta.SerialOrder_PlanResourceId.Name, worklineIds).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	datalist := make([]model.PackOrder, 0, 10)
	packMap := make(map[string]model.PackOrder)
	for _, v := range data {
		_, ok := packMap[v.PackOrderId]
		if !ok {
			packMap[v.PackOrderId] = v
			datalist = append(datalist, v)
		}
	}
	return datalist, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/PackOrderDAO.SelectClosedPackOrder
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectClosedPackOrder(startDayTime string, endDayTime string, worklineIds []string) ([]model.PackOrder, error) {

	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderStatus_PlantNr.ColumnName,
		meta.PackOrder_PackOrderId.ColumnName,
		meta.PackOrderStatus_PackOrderId.ColumnName)

	condition1 := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderItemLst_PlantNr.ColumnName,
		meta.PackOrder_PackOrderId.ColumnName,
		meta.PackOrderItemLst_PackOrderId.ColumnName)

	condition2 := fmt.Sprintf("%s = %s and %s = %s",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrderItemLst_PlantNr.ColumnName,
		omMeta.SerialOrder_SerialOrderId.ColumnName,
		meta.PackOrderItemLst_SerialOrderId.ColumnName)

	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.PackOrderStatus.TableName, condition).Join("LEFT", meta.PackOrderItemLst.TableName, condition1).Join("LEFT", omMeta.SerialOrder.TableName, condition2)
	parameters := []interface{}{impl.plantNr, model.PACK_LOCATION_ON_LINE, startDayTime, endDayTime, model.PACK_TYPE_STD, model.PACK_STATUS_CLOSED, model.PACK_STATUS_CLOSED, model.PACK_STATUS_CANCELED, model.PACK_STATUS_CANCELED}

	where := fmt.Sprintf("%s = ? and %s = ? and %s >= ? and %s < ? and %s = ? and ((%s = ? and %s = ? ) or (%s = ? and %s = ?))",
		meta.PackOrder_PlantNr.ColumnName,
		meta.PackOrder_PackLocation.ColumnName,
		meta.PackOrder_CloseTime.ColumnName,
		meta.PackOrder_CloseTime.ColumnName,
		meta.PackOrder_PackTypeId.ColumnName,
		meta.PackOrderStatus_Status.ColumnName,
		meta.PackOrderItemLst_Status.ColumnName,
		meta.PackOrderStatus_Status.ColumnName,
		meta.PackOrderItemLst_Status.ColumnName,
		)

	data := make([]model.PackOrderSerialOrder, 0, 10)
	err := session.Where(where, parameters...).In(omMeta.SerialOrder_PlanResourceId.Name, worklineIds).OrderBy(meta.PackOrder_CloseTime.SortColumnName).OrderBy(meta.PackOrder_PackOrderId.SortColumnName).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	datalist := make([]model.PackOrder, 0, 10)
	packMap := make(map[string]model.PackOrder)
	packOrderIdLi := make([]string, 0)
	for _, v := range data {
		_, ok := packMap[v.PackOrder.PackOrderId]
		if !ok {
			packOrderIdLi = append(packOrderIdLi, v.PackOrder.PackOrderId)
			packOrder := v.PackOrder
			packOrderItem := v.PackOrderItemLst
			packOrderItem.SerialOrder = v.SerialOrder
			packOrder.PackOrderItemLstLi = append(packOrder.PackOrderItemLstLi, packOrderItem)
			packMap[v.PackOrder.PackOrderId] = packOrder
		} else {
			packOrder := packMap[v.PackOrder.PackOrderId]
			packOrderItem := v.PackOrderItemLst
			packOrderItem.SerialOrder = v.SerialOrder
			packOrder.PackOrderItemLstLi = append(packOrder.PackOrderItemLstLi, packOrderItem)
			packMap[v.PackOrder.PackOrderId] = packOrder
		}
	}
	for _, packOrderId := range packOrderIdLi {
		packOrder := packMap[packOrderId]
		datalist = append(datalist, packOrder)
	}
	return datalist, nil
}