// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/jit"
	model "LAPP_ACURA_MOM_BACKEND/models/jit"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ShipOrderItemLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ShipOrderItemLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
type ShipOrderItemLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewShipOrderItemLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ShipOrderItemLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ShipOrderItemLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func NewShipOrderItemLstDAOImplement(session *xorm.Session, plantNr int, userid string) *ShipOrderItemLstDAOImplement {
	return &ShipOrderItemLstDAOImplement{session, &meta.ShipOrderItemLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) InsertOne(entity *model.ShipOrderItemLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) DeleteOne(shipOrderId string, pos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, shipOrderId, pos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) SelectOne(shipOrderId string, pos int) (*model.ShipOrderItemLst, error) {
	var data model.ShipOrderItemLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, shipOrderId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) UpdateOne(entity *model.ShipOrderItemLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.Insert
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) Insert(entities *[]model.ShipOrderItemLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.Delete
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) Delete(entities *[]model.ShipOrderItemLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderItemLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.Select
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ShipOrderItemLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderItemLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ShipOrderItemLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ShipOrderItemLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderItemLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ShipOrderItemLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ShipOrderItemLst, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.Update
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) Update(entities *[]model.ShipOrderItemLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ShipOrderItemLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderItemLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ShipOrderItemLst_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAOImplement.GetMaxPos
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) GetMaxPos(shipOrderId string) (int, error) {
	parameters := []interface{}{impl.plantNr, shipOrderId}
	where := fmt.Sprintf("%s = ? and %s = ?",
		meta.ShipOrderItemLst_PlantNr.ColumnName,
		meta.ShipOrderItemLst_ShipOrderId.ColumnName)
	var data model.ShipOrderItemLst
	ok, err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Desc(meta.ShipOrderItemLst_Pos.SortColumnName).Get(&data)
	if err != nil {
		return 0, err
	}
	if !ok {
		return 0, nil
	}
	return data.Pos, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderItemLstDAOImplement.SelectItemListWithData
 *
 ******************************************************************************/
func (impl *ShipOrderItemLstDAOImplement) SelectItemListWithData(shipOrderId string) ([]model.ShipOrderItemLstWithData, error) {
	parameters := []interface{}{impl.plantNr, shipOrderId}
	condition := fmt.Sprintf("%s = %s and %s = %s and %s = %s",
		meta.ShipOrderItemLst_PlantNr.ColumnName,
		meta.ShipOrderDataLst_PlantNr.ColumnName,
		meta.ShipOrderItemLst_ShipOrderId.ColumnName,
		meta.ShipOrderDataLst_ShipOrderId.ColumnName,
		meta.ShipOrderItemLst_Pos.ColumnName,
		meta.ShipOrderDataLst_ItemPos.ColumnName)
	where := fmt.Sprintf("%s = ? and %s = ?",
		meta.ShipOrderItemLst_PlantNr.ColumnName,
		meta.ShipOrderItemLst_ShipOrderId.ColumnName)
	data := make([]model.ShipOrderItemLstWithData, 0)
	err := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.ShipOrderDataLst.TableName, condition).Where(where, parameters...).Desc(meta.ShipOrderItemLst_Pos.SortColumnName).Find(&data)
	return data, err
}
