// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/jit"
	model "LAPP_ACURA_MOM_BACKEND/models/jit"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ShipOrderStatusDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ShipOrderStatus的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
type ShipOrderStatusDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewShipOrderStatusDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ShipOrderStatusDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ShipOrderStatusDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func NewShipOrderStatusDAOImplement(session *xorm.Session, plantNr int, userid string) *ShipOrderStatusDAOImplement {
	return &ShipOrderStatusDAOImplement{session, &meta.ShipOrderStatus, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) InsertOne(entity *model.ShipOrderStatus) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) DeleteOne(shipOrderId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, shipOrderId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) SelectOne(shipOrderId string) (*model.ShipOrderStatus, error) {
	var data model.ShipOrderStatus
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, shipOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) UpdateOne(entity *model.ShipOrderStatus) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.Insert
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) Insert(entities *[]model.ShipOrderStatus) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.Delete
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) Delete(entities *[]model.ShipOrderStatus) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatus_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.Select
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ShipOrderStatus, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatus_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ShipOrderStatus_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ShipOrderStatus, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatus_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ShipOrderStatus_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ShipOrderStatus, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.Update
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) Update(entities *[]model.ShipOrderStatus) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ShipOrderStatus, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatus_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ShipOrderStatus_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusDAO.SelectUnBackFlushedShipOrder
 *
 ******************************************************************************/
func (impl *ShipOrderStatusDAOImplement) SelectUnBackFlushedShipOrder() ([]model.ShipOrderWithStatus, error) {
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.ShipOrderStatus_PlantNr.ColumnName,
		meta.ShipOrder_PlantNr.ColumnName,
		meta.ShipOrderStatus_ShipOrderId.ColumnName,
		meta.ShipOrder_ShipOrderId.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.ShipOrder.TableName, condition)
	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatus_PlantNr.ColumnName)
	where += fmt.Sprintf(" and %s = ? and %s = ? and %s = ?",
		meta.ShipOrder_ShipType.ColumnName,
		meta.ShipOrderStatus_Status.ColumnName,
		meta.ShipOrderStatus_BackFlushedToggle.ColumnName)
	parameters = append(parameters, model.SHIP_TYPE_FORMAL, model.SHIP_STATUS_CLOSED, 0)
	result := make([]model.ShipOrderWithStatus, 0)
	err := session.Where(where, parameters...).OrderBy(meta.ShipOrder_ShipOrderId.ColumnName).Find(&result)
	return result, err
}