// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/jit"
	model "LAPP_ACURA_MOM_BACKEND/models/jit"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ShipOrderStatusHistoryDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ShipOrderStatusHistory的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
type ShipOrderStatusHistoryDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewShipOrderStatusHistoryDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ShipOrderStatusHistoryDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ShipOrderStatusHistoryDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func NewShipOrderStatusHistoryDAOImplement(session *xorm.Session, plantNr int, userid string) *ShipOrderStatusHistoryDAOImplement {
	return &ShipOrderStatusHistoryDAOImplement{session, &meta.ShipOrderStatusHistory, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) InsertOne(entity *model.ShipOrderStatusHistory) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) DeleteOne(shipOrderId string, pos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, shipOrderId, pos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) SelectOne(shipOrderId string, pos int) (*model.ShipOrderStatusHistory, error) {
	var data model.ShipOrderStatusHistory
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, shipOrderId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) UpdateOne(entity *model.ShipOrderStatusHistory) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.Insert
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) Insert(entities *[]model.ShipOrderStatusHistory) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.Delete
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) Delete(entities *[]model.ShipOrderStatusHistory) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatusHistory_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.Select
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ShipOrderStatusHistory, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatusHistory_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ShipOrderStatusHistory_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ShipOrderStatusHistory, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatusHistory_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ShipOrderStatusHistory_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ShipOrderStatusHistory, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.Update
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) Update(entities *[]model.ShipOrderStatusHistory) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ShipOrderStatusHistory, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ShipOrderStatusHistory_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ShipOrderStatusHistory_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/jit/ShipOrderStatusHistoryDAO.GetMaxPos
 *
 ******************************************************************************/
func (impl *ShipOrderStatusHistoryDAOImplement) GetMaxPos(shipOrderId string) (int, error) {
	parameters := []interface{}{impl.plantNr, shipOrderId}
	where := fmt.Sprintf("%s = ? and %s = ?",
		meta.ShipOrderStatusHistory_PlantNr.ColumnName,
		meta.ShipOrderStatusHistory_ShipOrderId.ColumnName)
	var data model.ShipOrderStatusHistory
	ok, err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Desc(meta.ShipOrderStatusHistory_Pos.SortColumnName).Get(&data)
	if err != nil {
		return 0, err
	}
	if !ok {
		return 0, nil
	}
	return data.Pos, nil
}
