// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/me"
	model "LAPP_ACURA_MOM_BACKEND/models/me"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ProductDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Product的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 15:22:21
 *
 ******************************************************************************/
type ProductDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewProductDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ProductDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ProductDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 15:22:21
 *
 ******************************************************************************/
func NewProductDAOImplement(session *xorm.Session, plantNr int, userid string) *ProductDAOImplement {
	return &ProductDAOImplement{session, &meta.Product, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) InsertOne(entity *model.Product) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) DeleteOne(productId string, projectId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, productId, projectId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) SelectOne(productId string, projectId string) (*model.Product, error) {
	var data model.Product
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, productId, projectId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	condition := fmt.Sprintf("%s = %s and %s = %s and %s = %s",
		meta.ProductFamilyRelate_PlantNr.ColumnName,
		meta.ProductFamily_PlantNr.ColumnName,
		meta.ProductFamilyRelate_ProductFamilyId.ColumnName,
		meta.ProductFamily_ProductFamilyId.ColumnName,
		meta.ProductFamilyRelate_ProjectId.ColumnName,
		meta.ProductFamily_ProjectId.ColumnName)
	session := impl.session.Table(meta.ProductFamilyRelate.TableName).Join("LEFT", meta.ProductFamily.TableName, condition)
	var productFamilyDataLi []model.ProductFamilyRelateWithData
	err = session.Where(fmt.Sprintf("%s = ? and %s = ?",
		meta.ProductFamilyRelate_ProductId.ColumnName,
		meta.ProductFamilyRelate_ProjectId.ColumnName), productId, projectId).Find(&productFamilyDataLi)
	//查询配置
	//var relate []model.ProductFamilyRelate
	//err = impl.session.Table(meta.ProductFamilyRelate.TableName).Where(fmt.Sprintf("%s = ? and %s = ?",
	//	meta.ProductFamilyRelate_ProductId.ColumnName,
	//	meta.ProductFamilyRelate_ProjectId.ColumnName), data.ProductId, data.ProjectId).Find(&relate)
	//if err != nil {
	//	return nil, err
	//}
	//var projectId []string
	//var familyId []string
	//familyCount := make(map[string]int)
	//for _, item := range productFamilyDataLi {
	//	//projectId = append(projectId, v.ProjectId)
	//	familyId = append(familyId, item.ProductFamilyRelate.ProductFamilyId)
	//	familyCount[item.ProductFamilyRelate.ProductFamilyId] = item.ProductFamilyRelate.Count
	//}
	//查询车型
	//var project []model.Project
	//_ = impl.session.Table(meta.Project.TableName).In("ProjectId", projectId).Find(&project)
	//查询配置
	//var family []model.ProductFamily
	//_ = impl.session.Table(meta.ProductFamily.TableName).In("ProductFamilyId", familyId).Find(&family)
	//配置map
	//familyMap := make(map[string][]model.ProductFamily)
	familyLi := make([]model.ProductFamily, 0, len(productFamilyDataLi))
	for _, item := range productFamilyDataLi {
		var family model.ProductFamily
		family = item.ProductFamily
		family.Count = item.ProductFamilyRelate.Count
		familyLi = append(familyLi, family)
		//v.Count = familyCount[v.ProductFamilyId]
		//familyMap[v.ProjectId] = append(familyMap[v.ProjectId], v)
	}
	//将配置导入车型
	//for k, v := range project {
	//	familyList, ok := familyMap[v.ProjectId]
	//	if ok {
	//		project[k].ProductFamily = familyList
	//	}
	//}
	//data.Project = project
	data.ProductFamily = familyLi
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) UpdateOne(entity *model.Product) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.Insert
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) Insert(entities *[]model.Product) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.Delete
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) Delete(entities *[]model.Product) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.Product_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.Select
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Product, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.Product_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.Product_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.Product, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.Product_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.Product_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Product, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.Update
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) Update(entities *[]model.Product) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/me/ProductDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ProductDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.Product, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.Product_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.Product_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
