// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meMeta "LAPP_ACURA_MOM_BACKEND/meta/me"
	meta "LAPP_ACURA_MOM_BACKEND/meta/om"
	common "LAPP_ACURA_MOM_BACKEND/models/base"
	model "LAPP_ACURA_MOM_BACKEND/models/om"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : SerialOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : SerialOrder的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-20 13:07:32
 *
 ******************************************************************************/
type SerialOrderDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewSerialOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SerialOrderDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : SerialOrderDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-20 13:07:32
 *
 ******************************************************************************/
func NewSerialOrderDAOImplement(session *xorm.Session, plantNr int, userid string) *SerialOrderDAOImplement {
	return &SerialOrderDAOImplement{session, &meta.SerialOrder, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.InsertOne
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) InsertOne(entity *model.SerialOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) DeleteOne(serialOrderId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, serialOrderId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectOne
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectOne(serialOrderId string) (*model.SerialOrder, error) {
	var data model.SerialOrder
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, serialOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) UpdateOne(entity *model.SerialOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectBySerialOrder
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectBySerialOrder(serialOrderId string) (*model.SerialOrder, error) {
	var data model.SerialOrder
	ok, err := impl.session.Table(impl.meta.TableName).Where("PlantNr = ? and SerialOrderId = ?", impl.plantNr, serialOrderId).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.UpdateInfo
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) UpdateInfo(entity *model.SerialOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).Where("PlantNr = ? and SerialOrderId = ?", impl.plantNr, entity.SerialOrderId).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.Insert
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) Insert(entities *[]model.SerialOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.Delete
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) Delete(entities *[]model.SerialOrder) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.Select
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.SerialOrder, error) {
	data := make([]model.VOmSerialorder, 0)
	session := impl.session.Table(impl.meta.TableName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	session = session.Join("LEFT", meta.SerialOrderStatus.TableName, condition)

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.SerialOrder_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	serialOrderLi := make([]model.SerialOrder, 0, len(data))
	for _, item := range data {
		var serialOrder model.SerialOrder
		serialOrder = item.SerialOrder
		serialOrder.SerialOrderStatus = item.SerialOrderStatus
		serialOrderLi = append(serialOrderLi, serialOrder)
	}
	return serialOrderLi, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.SerialOrder_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.SerialOrder, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.Update
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) Update(entities *[]model.SerialOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.SerialOrder, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.SerialOrder_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectByWorkOrderId
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectByWorkOrderId(workOrderId string, status int) (serialOrderLi []model.SerialOrder, err error) {
	data := make([]model.VOmSerialorder, 0)

	session := impl.session.Table(impl.meta.TableName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_WorkOrderId.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName)
	//err = session.Join("LEFT", meta.SerialOrderStatus.TableName, condition).Where(where, impl.plantNr, workOrderId, common.WO_STATUS_LOCKED).Asc(meta.SerialOrder_SerialOrderId.ColumnName).Find(&data)
	err = session.Join("LEFT", meta.SerialOrderStatus.TableName, condition).Where(where, impl.plantNr, workOrderId, status).Find(&data)
	if err != nil {
		return nil, err
	}
	serialOrderLi = make([]model.SerialOrder, 0, len(data))
	for _, item := range data {
		var serialOrder model.SerialOrder
		serialOrder = item.SerialOrder
		serialOrder.SerialOrderStatus = item.SerialOrderStatus
		serialOrderLi = append(serialOrderLi, serialOrder)
	}
	return serialOrderLi, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectInfo
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectInfo(workOrderId string) (data model.SerialOrder, err error) {
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId}).Get(&data)
	if err != nil {
		return data, grmi.NewDataBaseError(err)
	}
	if !ok {
		return data, nil
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.GetLineWIPQty
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) GetLineWIPQty(lineid string) (wipqty int, err error) {
	var (
		totalrow    int64
		serialOrder model.SerialOrder
	)

	session := impl.session.Table(impl.meta.TableName)
	wipqty = 0
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	where := fmt.Sprintf("%s = ? and %s = ? and %s >= ? and %s < ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_PlanResourceId.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName)
	if totalrow, err = session.Join("INNER", meta.SerialOrderStatus.TableName,
		condition).Where(where, impl.plantNr, lineid, common.WO_STATUS_RELEASED, common.WO_STATUS_FINISHED).Count(&serialOrder); err != nil {
		return
	}
	wipqty = int(totalrow)
	return
}

// SelectOrderByResource 产线排序页面查询产线上工单
func (impl *SerialOrderDAOImplement) SelectOrderByResource(resourceId string, status int, planDate string, seqStart int, seqEnd int, custOrderId, serialOrderId string, seq bool, urgency bool, artId string, pageNumber int64, pageSize int64) (grmi.PagingResult, error) {
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	parameters := []interface{}{impl.plantNr, resourceId}
	where := fmt.Sprintf(" %s = ? and %s = ?", meta.SerialOrder_PlantNr.ColumnName, meta.SerialOrder_PlanResourceId.ColumnName)
	joinStr := " left join " + meta.SerialOrderStatus.TableName + " on " + condition + " "
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.SerialOrderStatus.TableName, condition).Where(where, parameters...)
	// 紧急工单页查询
	if urgency {
		where += fmt.Sprintf(" and %s > ? and %s < ? ", meta.SerialOrder_Priority.ColumnName, meta.SerialOrderStatus_Status.ColumnName)
		parameters = append(parameters, 0, common.WO_STATUS_FINISHED)
		session = session.Where(fmt.Sprintf("%s > ? and %s < ?", meta.SerialOrder_Priority.ColumnName, meta.SerialOrderStatus_Status.ColumnName), 0, common.WO_STATUS_FINISHED)
		count, err := session.Count(impl.meta.Indicator)
		if err != nil {
			return grmi.EmptyPagingResult, err
		}
		orderBy := " order by " + meta.SerialOrder_PlantNr.ColumnName + ", " + meta.SerialOrder_Priority.ColumnName + " desc "
		data := make([]model.VOmSerialorder, 0, 10)
		parameters = append(parameters, (pageNumber-1)*pageSize, pageSize)
		err = impl.session.Table(impl.meta.TableName).SQL(fmt.Sprintf(" select %s.*, %s.* from "+impl.meta.TableName+joinStr+" where "+where+orderBy+" offset ? row fetch next ? row only",
			meta.SerialOrder.TableName, meta.SerialOrderStatus.TableName), parameters...).Find(&data)
		if err != nil {
			return grmi.EmptyPagingResult, err
		}
		return grmi.PagingResult{Records: data, Count: count, PageNumber: pageNumber, PageSize: pageSize}, nil
	} else {
		// 排序工单页查询
		where += fmt.Sprintf(" and %s = ? ", meta.SerialOrder_Priority.ColumnName)
		parameters = append(parameters, 0)
		session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrder_Priority.ColumnName), 0)
		// 已排序工单查询
		if seq {
			if status == 0 {
				where += fmt.Sprintf(" and %s >= ? and %s < ? ", meta.SerialOrderStatus_Status.ColumnName, meta.SerialOrderStatus_Status.ColumnName)
				parameters = append(parameters, common.WO_STATUS_PLANNED, common.WO_STATUS_FINISHED)
				session = session.Where(fmt.Sprintf("%s >= ? and %s < ? ", meta.SerialOrderStatus_Status.ColumnName, meta.SerialOrderStatus_Status.ColumnName), common.WO_STATUS_PLANNED, common.WO_STATUS_FINISHED)
			} else {
				where += fmt.Sprintf(" and %s = ? ", meta.SerialOrderStatus_Status.ColumnName)
				parameters = append(parameters, status)
				session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrderStatus_Status.ColumnName), status)
			}
			if planDate != "" {
				where += fmt.Sprintf(" and %s = ? ", meta.SerialOrder_PlanStartDate.ColumnName)
				parameters = append(parameters, planDate)
				session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrder_PlanStartDate.ColumnName), planDate)
			}
			if seqStart != 0 {
				where += fmt.Sprintf(" and %s >= ? ", meta.SerialOrder_SchedKey.ColumnName)
				parameters = append(parameters, seqStart)
				session = session.Where(fmt.Sprintf("%s >= ? ", meta.SerialOrder_SchedKey.ColumnName), seqStart)
			}
			if seqEnd != 0 {
				where += fmt.Sprintf(" and %s <= ? ", meta.SerialOrder_SchedKey.ColumnName)
				parameters = append(parameters, seqEnd)
				session = session.Where(fmt.Sprintf("%s <= ? ", meta.SerialOrder_SchedKey.ColumnName), seqEnd)
			}
		} else {
			where += fmt.Sprintf(" and %s = ? ", meta.SerialOrderStatus_Status.ColumnName)
			parameters = append(parameters, common.WO_STATUS_UNPLANNED)
			session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrderStatus_Status.ColumnName), common.WO_STATUS_UNPLANNED)
		}
		if custOrderId != "" {
			where += fmt.Sprintf(" and %s = ? ", meta.SerialOrder_CustOrderId.ColumnName)
			parameters = append(parameters, custOrderId)
			session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrder_CustOrderId.ColumnName), custOrderId)
		}
		if serialOrderId != "" {
			where += fmt.Sprintf(" and %s = ? ", meta.SerialOrder_SerialOrderId.ColumnName)
			parameters = append(parameters, serialOrderId)
			session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrder_SerialOrderId.ColumnName), serialOrderId)
		}
		if artId != "" {
			where += fmt.Sprintf(" and %s = ? ", meta.SerialOrder_ArtId.ColumnName)
			parameters = append(parameters, artId)
			session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrder_ArtId.ColumnName), artId)
		}
		count, err := session.Count(impl.meta.Indicator)
		if err != nil {
			return grmi.EmptyPagingResult, err
		}
		orderBy := " order by " + meta.SerialOrder_PlantNr.ColumnName + ", " + meta.SerialOrder_SchedKey.ColumnName + ", " + meta.SerialOrder_OrderType.ColumnName + " desc"
		data := make([]model.VOmSerialorder, 0, 10)
		parameters = append(parameters, (pageNumber-1)*pageSize, pageSize)
		err = impl.session.Table(impl.meta.TableName).SQL(fmt.Sprintf(" select %s.*, %s.* from "+impl.meta.TableName+joinStr+" where "+where+orderBy+" offset ? row fetch next ? row only",
			meta.SerialOrder.TableName, meta.SerialOrderStatus.TableName), parameters...).Find(&data)
		if err != nil {
			return grmi.EmptyPagingResult, err
		}
		return grmi.PagingResult{Records: data, Count: count, PageNumber: pageNumber, PageSize: pageSize}, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectByCustOrder
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectByCustOrder(custOrderId string, status int) (serialOrderLi []model.SerialOrder, err error) {
	data := make([]model.VOmSerialorder, 0)

	session := impl.session.Table(impl.meta.TableName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_CustOrderId.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName)
	err = session.Join("INNER", meta.SerialOrderStatus.TableName, condition).Where(where, impl.plantNr, custOrderId, status).Find(&data)
	if err != nil {
		return nil, err
	}
	serialOrderLi = make([]model.SerialOrder, 0, len(data))
	for _, item := range data {
		var serialOrder model.SerialOrder
		serialOrder = item.SerialOrder
		serialOrder.SerialOrderStatus = item.SerialOrderStatus
		serialOrderLi = append(serialOrderLi, serialOrder)
	}
	return serialOrderLi, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectBySyncKey
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectBySyncKey(custOrderId string, syncKey string) (serialOrderLi []model.SerialOrder, err error) {
	data := make([]model.VOmSerialorder, 0)

	session := impl.session.Table(impl.meta.TableName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ? and %s = ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_CustOrderId.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName,
		meta.SerialOrder_SyncKey.ColumnName)
	err = session.Join("INNER", meta.SerialOrderStatus.TableName, condition).Where(where, impl.plantNr, custOrderId, common.WO_STATUS_LOCKED, syncKey).Find(&data)
	if err != nil {
		return nil, err
	}
	serialOrderLi = make([]model.SerialOrder, 0, len(data))
	for _, item := range data {
		var serialOrder model.SerialOrder
		serialOrder = item.SerialOrder
		serialOrder.SerialOrderStatus = item.SerialOrderStatus
		serialOrderLi = append(serialOrderLi, serialOrder)
	}
	return serialOrderLi, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectSerialOrderIdBySyncKey
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectSerialOrderIdBySyncKey(syncKeyLi []string) ([]string, error) {
	data := make([]string, 0)
	err := impl.session.Table(impl.meta.TableName).Cols(meta.SerialOrder_SerialOrderId.SortColumnName).In(meta.SerialOrder_SyncKey.SortColumnName, syncKeyLi).Find(&data)
	return data, err
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.UpdateBackFlushFlag
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) UpdateBackFlushFlag(serialOrderIdLi []string) (int64, error) {
	where := fmt.Sprintf("%s = ? and %s = ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_BackFlushFlag.ColumnName,
		)
	parameters := []interface{}{impl.plantNr, 0}
	inStr := fmt.Sprintf(" and %s in ( ", meta.SerialOrder_SerialOrderId.ColumnName)
	for index, serialOrderId := range serialOrderIdLi {
		if index != 0 {
			inStr += ","
		}
		inStr += `'` + serialOrderId + `'`
	}
	inStr += " ) "
	where += inStr
	updateMap := make(map[string]bool)
	updateMap[meta.SerialOrder_BackFlushFlag.Name] = true
	count, err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Cols(meta.SerialOrder_BackFlushFlag.ColumnName).Update(&updateMap)
	return count, err
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.UpdateBackFlushFlag
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) UpdateShipBackFlushFlag(serialOrderIdLi []string) (int64, error) {
	where := fmt.Sprintf("%s = ? and %s = ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_ShipBackFlush.ColumnName,
	)
	parameters := []interface{}{impl.plantNr, 0}
	inStr := fmt.Sprintf(" and %s in ( ", meta.SerialOrder_SerialOrderId.ColumnName)
	for index, serialOrderId := range serialOrderIdLi {
		if index != 0 {
			inStr += ","
		}
		inStr += `'` + serialOrderId + `'`
	}
	inStr += " ) "
	where += inStr
	updateMap := make(map[string]bool)
	updateMap[meta.SerialOrder_ShipBackFlush.Name] = true
	count, err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Cols(meta.SerialOrder_ShipBackFlush.Name).Update(&updateMap)
	return count, err
}

// SelectTraceOrder 查询展示的工单
func (impl *SerialOrderDAOImplement) SelectTraceOrder(workLineId , serialOrderId , start, end string, status int, pageNumber int64, pageSize int64) (grmi.PagingResult, error) {
	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.SerialOrderStatus.TableName, condition)
	session = session.Where(where, parameters...)
	if workLineId != "" {
		where += fmt.Sprintf(" and %s = ? ", meta.SerialOrder_UsedResourceId.ColumnName)
		parameters = append(parameters, workLineId)
		session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrder_UsedResourceId.ColumnName), workLineId)
	}
	if serialOrderId != "" {
		where += fmt.Sprintf(" and %s = ? ", meta.SerialOrder_SerialOrderId.ColumnName)
		parameters = append(parameters, serialOrderId)
		session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrder_SerialOrderId.ColumnName), serialOrderId)
	}
	if status != 0 {
		where += fmt.Sprintf(" and %s = ? ", meta.SerialOrderStatus_Status.ColumnName)
		parameters = append(parameters, status)
		session = session.Where(fmt.Sprintf("%s = ? ", meta.SerialOrderStatus_Status.ColumnName), status)
	}
	if start != "" {
		where += fmt.Sprintf(" and %s >= ? ", meta.SerialOrder_ActStartTime.ColumnName)
		parameters = append(parameters, start)
		session = session.Where(fmt.Sprintf(" %s >= ? ", meta.SerialOrder_ActStartTime.ColumnName), start)
		if end != "" {
			where += fmt.Sprintf(" and %s <= ? ", meta.SerialOrder_ActStartTime.ColumnName)
			parameters = append(parameters, end)
			session = session.Where(fmt.Sprintf(" %s <= ? ", meta.SerialOrder_ActStartTime.ColumnName), end)
		}
	}
	count, err := session.Count(model.VOmSerialorder{})
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	orderBy := "order by " + meta.SerialOrder_ActStartTime.ColumnName
	parameters = append(parameters, pageSize*(pageNumber-1), pageSize)
	data := make([]model.VOmSerialorder, 0, 10)
	err = impl.session.Table(impl.meta.TableName).SQL(fmt.Sprintf("select %s.*,%s.* from %s left join %s on %s where "+where+orderBy+" offset ? row fetch next ? row only",
		meta.SerialOrder.TableName,
		meta.SerialOrderStatus.TableName,
		meta.SerialOrder.TableName,
		meta.SerialOrderStatus.TableName,
		condition,
	), parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{
		Records: data,
		Count: count,
		PageNumber: pageNumber,
		PageSize: pageSize,
	}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectUnOnGoingSerialOrder
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectUnOnGoingSerialOrder(custOrderId string) ([]model.VOmSerialorder, error) {
	data := make([]model.VOmSerialorder, 0)
	parameters := []interface{}{impl.plantNr, custOrderId, common.WO_STATUS_RELEASED, common.ORDER_TYPE_SEQ}
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ? and %s = ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_CustOrderId.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName,
		meta.SerialOrder_OrderType.ColumnName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.SerialOrderStatus.TableName, condition)
	err := session.Where(where, parameters...).Desc(meta.SerialOrder_SyncKey.SortColumnName).Find(&data)
	return data, err
}


/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectByOriginSerialOrderId
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectByOriginSerialOrderId(serialOrderId string) (*model.SerialOrder, error) {
	var data model.SerialOrder
	ok, err := impl.session.Table(impl.meta.TableName).Where("PlantNr = ? and SelectByOriginSerialOrderId = ?", impl.plantNr, serialOrderId).Desc("CreateTime").Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}


/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectByCustOrderIdForDashboard
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectByCustOrderIdForDashboard(custOrderId, start, end string) ([]model.SerialOrder, error) {
	parameters := []interface{}{impl.plantNr, custOrderId, common.ORDER_TYPE_SEQ, start, end, common.QualityCheck_STATUS_OK, common.QualityCheck_STATUS_FAIL}
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ? and %s >= ? and %s <= ? and (%s = ? or %s = ?) ",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_CustOrderId.ColumnName,
		meta.SerialOrder_OrderType.ColumnName,
		meta.SerialOrder_ActStartTime.ColumnName,
		meta.SerialOrder_ActEndTime.ColumnName,
		meta.SerialOrder_QualityCheck.ColumnName,
		meta.SerialOrder_QualityCheck.ColumnName,
	)
	data := make([]model.SerialOrder, 0)
	err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).OrderBy(meta.SerialOrder_ActEndTime.SortColumnName).Find(&data)
	return data, err
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDAO.SelectByCustOrder
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectSerialOrderByCustOrder(custOrderId string) (serialOrderLi []model.SerialOrder, err error) {
	data := make([]model.VOmSerialorder, 0)

	session := impl.session.Table(impl.meta.TableName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)

	condition2 := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meMeta.Product_PlantNr.ColumnName,
		meta.SerialOrder_ArtId.ColumnName,
		meMeta.Product_ProductId.ColumnName)

	where := fmt.Sprintf("%s = ? and %s = ? and %s <= ? and %s = ? and %s = ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_CustOrderId.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName,
		meMeta.Product_CreatePackOrderToggle.ColumnName,
		meta.SerialOrder_OrderType.ColumnName,
		)
	err = session.Join("INNER", meta.SerialOrderStatus.TableName, condition).Join("INNER",meMeta.Product.TableName,condition2).Where(where, impl.plantNr, custOrderId, common.WO_STATUS_FINISHED,1,"SEQ").Find(&data)
	if err != nil {
		return nil, err
	}
	serialOrderLi = make([]model.SerialOrder, 0, len(data))
	for _, item := range data {
		var serialOrder model.SerialOrder
		serialOrder = item.SerialOrder
		serialOrder.SerialOrderStatus = item.SerialOrderStatus
		serialOrderLi = append(serialOrderLi, serialOrder)
	}
	return serialOrderLi, nil
}