// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/om"
	model "LAPP_ACURA_MOM_BACKEND/models/om"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : SerialOrderDisassembleDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : SerialOrderDisassemble的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-03-28 09:55:48
 *
 ******************************************************************************/
type SerialOrderDisassembleDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewSerialOrderDisassembleDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SerialOrderDisassembleDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : SerialOrderDisassembleDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-03-28 09:55:48
 *
 ******************************************************************************/
func NewSerialOrderDisassembleDAOImplement(session *xorm.Session, plantNr int, userid string) *SerialOrderDisassembleDAOImplement {
	return &SerialOrderDisassembleDAOImplement{session, &meta.SerialOrderDisassemble, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.InsertOne
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) InsertOne(entity *model.SerialOrderDisassemble) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) DeleteOne(serialOrderId string, pos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, serialOrderId, pos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.SelectOne
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) SelectOne(serialOrderId string, pos int) (*model.SerialOrderDisassemble, error) {
	var data model.SerialOrderDisassemble
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, serialOrderId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) UpdateOne(entity *model.SerialOrderDisassemble) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.Insert
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) Insert(entities *[]model.SerialOrderDisassemble) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.Delete
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) Delete(entities *[]model.SerialOrderDisassemble) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderDisassemble_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.Select
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.SerialOrderDisassemble, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderDisassemble_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.SerialOrderDisassemble_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.SerialOrderDisassemble, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.SelectCols
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) SelectCols(predicates []grmi.Predicate, orderByFields []grmi.Field, cloumns []string) ([]map[string]interface{}, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderDisassemble_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.SerialOrderDisassemble_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]map[string]interface{}, 0, 10)
	err := session.Cols(cloumns...).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderDisassemble_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.SerialOrderDisassemble_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.SerialOrderDisassemble, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.Update
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) Update(entities *[]model.SerialOrderDisassemble) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.SerialOrderDisassemble, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderDisassemble_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.SerialOrderDisassemble_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}


/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderDisassembleDAO.GetMaxPos
 *
 ******************************************************************************/
func (impl *SerialOrderDisassembleDAOImplement) GetMaxPos(serialOrderId string) (int, error) {

	parameters := []interface{}{impl.plantNr, serialOrderId}
	where := fmt.Sprintf("%s = ? and %s = ?", meta.SerialOrderDisassemble_PlantNr.ColumnName,
		meta.SerialOrderDisassemble_SerialOrderId.ColumnName)
	var maxPos int
	ok, err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Desc(meta.SerialOrderDisassemble_Pos.Name).Cols(meta.SerialOrderDisassemble_Pos.Name).Get(&maxPos)
	if err != nil {
		return 0, err
	}
	if !ok {
		return 0, nil
	}
	return maxPos, nil
}
