// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	baseMeta "LAPP_ACURA_MOM_BACKEND/meta/base"
	meta "LAPP_ACURA_MOM_BACKEND/meta/om"
	model "LAPP_ACURA_MOM_BACKEND/models/om"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : SerialOrderPOLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : SerialOrderPOLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
type SerialOrderPOLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewSerialOrderPOLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SerialOrderPOLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : SerialOrderPOLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func NewSerialOrderPOLstDAOImplement(session *xorm.Session, plantNr int, userid string) *SerialOrderPOLstDAOImplement {
	return &SerialOrderPOLstDAOImplement{session, &meta.SerialOrderPOLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) InsertOne(entity *model.SerialOrderPOLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) DeleteOne(serialOrderId string, pO string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, serialOrderId, pO}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) SelectOne(serialOrderId string, pO string) (*model.SerialOrderPOLst, error) {
	var data model.SerialOrderPOLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, serialOrderId, pO}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) UpdateOne(entity *model.SerialOrderPOLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.Insert
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) Insert(entities *[]model.SerialOrderPOLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.Delete
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) Delete(entities *[]model.SerialOrderPOLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderPOLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.Select
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.SerialOrderPOLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderPOLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.SerialOrderPOLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.SerialOrderPOLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderPOLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.SerialOrderPOLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.SerialOrderPOLst, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.Update
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) Update(entities *[]model.SerialOrderPOLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.SerialOrderPOLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrderPOLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.SerialOrderPOLst_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := session.Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/om/SerialOrderPOLstDAO.SelectBySerialOrderId
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) SelectBySerialOrderId(serialOrderId string, workLineId string) ([]model.SerialOrderPOLst, error) {
	sql := "SELECT po.* FROM ( SELECT * FROM OM_SerialOrderPOLst WHERE OM_SerialOrderPOLst.PlantNr = ? AND OM_SerialOrderPOLst.SerialOrderId = ? ) po LEFT JOIN WorkLineProcessLst ON po.PlantNr = WorkLineProcessLst.PlantNr AND po.PO = WorkLineProcessLst.PO WHERE WorkLineProcessLst.WorkLineId = ? ORDER BY WorkLineProcessLst.Pos"
	parameters := []interface{}{impl.plantNr, serialOrderId, workLineId}
	data := make([]model.SerialOrderPOLst, 0)
	err := impl.session.Table(impl.meta.TableName).SQL(sql, parameters...).Find(&data)
	return data, err
}

// SelectWithPO 查询工单工序操作结果及工序数据
func (impl *SerialOrderPOLstDAOImplement) SelectWithPO(serialOrderId string, workLineId string) ([]model.SerialOrderPOWithProcess, error) {
	poCondition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrderPOLst_PlantNr.ColumnName,
		baseMeta.Process_PlantNr.ColumnName,
		meta.SerialOrderPOLst_PO.ColumnName,
		baseMeta.Process_PO.ColumnName)
	wpCondition := fmt.Sprintf("%s = %s and %s = %s",
		baseMeta.Process_PlantNr.ColumnName,
		baseMeta.WorkLineProcessLst_PlantNr.ColumnName,
		baseMeta.Process_PO.ColumnName,
		baseMeta.WorkLineProcessLst_PO.ColumnName,
	)
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ?",
		meta.SerialOrderPOLst_PlantNr.ColumnName,
		meta.SerialOrderPOLst_SerialOrderId.ColumnName,
		baseMeta.WorkLineProcessLst_WorkLineId.ColumnName)
	parameters := []interface{}{impl.plantNr, serialOrderId, workLineId}
	result := make([]model.SerialOrderPOWithProcess, 0)
	err := impl.session.Table(impl.meta.TableName).Join("LEFT", baseMeta.Process.TableName, poCondition).
		Join("LEFT", baseMeta.WorkLineProcessLst.TableName, wpCondition).
		Where(where, parameters...).OrderBy(baseMeta.WorkLineProcessLst_Pos.ColumnName).Find(&result)
	return result, err
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/base/LabelHeadDAO.SelectOrderAllPo
 *
 ******************************************************************************/
func (impl *SerialOrderPOLstDAOImplement) SelectOrderAllPo(serialOrderId string) ([]string, error) {

	parameters := []interface{}{impl.plantNr, serialOrderId}
	where := fmt.Sprintf("%s = ? and %s = ?", meta.SerialOrderPOLst_PlantNr.ColumnName, meta.SerialOrderPOLst_SerialOrderId.ColumnName)
	result := make([]string, 0)
	err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Cols(meta.SerialOrderPOLst_PO.ColumnName).Find(&result)
	return result, err
}


// SelectWithPO 查询工单工序操作结果及工序数据
func (impl *SerialOrderPOLstDAOImplement) selectOrderPoData(serialOrderIdLi []string, workLineId string) ([]model.SerialOrderPOWithProcess, error) {
	poCondition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrderPOLst_PlantNr.ColumnName,
		baseMeta.Process_PlantNr.ColumnName,
		meta.SerialOrderPOLst_PO.ColumnName,
		baseMeta.Process_PO.ColumnName)
	wpCondition := fmt.Sprintf("%s = %s and %s = %s",
		baseMeta.Process_PlantNr.ColumnName,
		baseMeta.WorkLineProcessLst_PlantNr.ColumnName,
		baseMeta.Process_PO.ColumnName,
		baseMeta.WorkLineProcessLst_PO.ColumnName,
	)
	where := fmt.Sprintf("%s = ? and %s = ? ",
		meta.SerialOrderPOLst_PlantNr.ColumnName,
		baseMeta.WorkLineProcessLst_WorkLineId.ColumnName)
	parameters := []interface{}{impl.plantNr, workLineId}
	result := make([]model.SerialOrderPOWithProcess, 0)
	err := impl.session.Table(impl.meta.TableName).Join("LEFT", baseMeta.Process.TableName, poCondition).
		Join("LEFT", baseMeta.WorkLineProcessLst.TableName, wpCondition).
		Where(where, parameters...).OrderBy(baseMeta.WorkLineProcessLst_Pos.ColumnName).Find(&result)
	return result, err
}


// SelectByOrderLi 查询工单工序操作结果及工序数据
func (impl *SerialOrderPOLstDAOImplement) SelectByOrderLi(serialOrderIdLi []interface{}, workLineId string) ([]model.SerialOrderPOWithProcess, error) {
	poCondition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrderPOLst_PlantNr.ColumnName,
		baseMeta.Process_PlantNr.ColumnName,
		meta.SerialOrderPOLst_PO.ColumnName,
		baseMeta.Process_PO.ColumnName)
	wpCondition := fmt.Sprintf("%s = %s and %s = %s",
		baseMeta.Process_PlantNr.ColumnName,
		baseMeta.WorkLineProcessLst_PlantNr.ColumnName,
		baseMeta.Process_PO.ColumnName,
		baseMeta.WorkLineProcessLst_PO.ColumnName,
	)
	where := fmt.Sprintf("%s = ? and %s = ?",
		meta.SerialOrderPOLst_PlantNr.ColumnName,
		baseMeta.WorkLineProcessLst_WorkLineId.ColumnName)
	parameters := []interface{}{impl.plantNr, workLineId}
	result := make([]model.SerialOrderPOWithProcess, 0)
	err := impl.session.Table(impl.meta.TableName).Join("LEFT", baseMeta.Process.TableName, poCondition).
		Join("LEFT", baseMeta.WorkLineProcessLst.TableName, wpCondition).
		Where(where, parameters...).In(meta.SerialOrderPOLst_SerialOrderId.ColumnName, serialOrderIdLi).OrderBy(baseMeta.WorkLineProcessLst_Pos.SortColumnName).OrderBy(meta.SerialOrderPOLst_CreateTime.SortColumnName).Find(&result)
	return result, err
}