// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	meta "LAPP_ACURA_MOM_BACKEND/meta/pln"
	model "LAPP_ACURA_MOM_BACKEND/models/pln"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ToyotaDeliveryOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ToyotaDeliveryOrder的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-26 09:51:03
 *
 ******************************************************************************/
type ToyotaDeliveryOrderDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewToyotaDeliveryOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ToyotaDeliveryOrderDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ToyotaDeliveryOrderDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-26 09:51:03
 *
 ******************************************************************************/
func NewToyotaDeliveryOrderDAOImplement(session *xorm.Session, plantNr int, userid string) *ToyotaDeliveryOrderDAOImplement {
	return &ToyotaDeliveryOrderDAOImplement{session, &meta.ToyotaDeliveryOrder, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) InsertOne(entity *model.ToyotaDeliveryOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) DeleteOne(demandId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, demandId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) SelectOne(demandId string) (*model.ToyotaDeliveryOrder, error) {
	var data model.ToyotaDeliveryOrder
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, demandId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) UpdateOne(entity *model.ToyotaDeliveryOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.Insert
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) Insert(entities *[]model.ToyotaDeliveryOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.Delete
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) Delete(entities *[]model.ToyotaDeliveryOrder) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ToyotaDeliveryOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.Select
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ToyotaDeliveryOrder, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ToyotaDeliveryOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ToyotaDeliveryOrder_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ToyotaDeliveryOrder, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.SelectCols
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) SelectCols(predicates []grmi.Predicate, orderByFields []grmi.Field, cloumns []string) ([]map[string]interface{}, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ToyotaDeliveryOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ToyotaDeliveryOrder_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]map[string]interface{}, 0, 10)
	err := session.Cols(cloumns...).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ToyotaDeliveryOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ToyotaDeliveryOrder_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			if orderBy == " order by " {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ToyotaDeliveryOrder, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from ["+impl.meta.TableName+"]"+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.Update
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) Update(entities *[]model.ToyotaDeliveryOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ToyotaDeliveryOrder, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ToyotaDeliveryOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ToyotaDeliveryOrder_LastUser.Name)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.GetMaxSortNr
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) GetMaxSortNr(projectId string) (int, error) {

	parameters := []interface{}{impl.plantNr, projectId}
	where := fmt.Sprintf("%s = ? and %s = ?",
		meta.ToyotaDeliveryOrder_PlantNr.ColumnName,
		meta.ToyotaDeliveryOrder_ProjectId.ColumnName)
	var data int
	ok, err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Desc(meta.ToyotaDeliveryOrder_SortNr.Name).Cols(meta.ToyotaDeliveryOrder_SortNr.UrlParameterName).Get(&data)
	if err != nil {
		return 0, err
	}
	if !ok {
		return 0, nil
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.SelectTopOne
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) SelectTopOne(predicates []grmi.Predicate, orderByFields []grmi.Field) (*model.ToyotaDeliveryOrder, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ToyotaDeliveryOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ToyotaDeliveryOrder_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.SortColumnName)
		}
	}

	var data model.ToyotaDeliveryOrder
	ok, err := session.Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_ACURA_MOM_BACKEND/dao/pln/ToyotaDeliveryOrderDAO.SelectTopOneDesc
 *
 ******************************************************************************/
func (impl *ToyotaDeliveryOrderDAOImplement) SelectTopOneDesc(predicates []grmi.Predicate, orderByFields []grmi.Field) (*model.ToyotaDeliveryOrder, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ToyotaDeliveryOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ToyotaDeliveryOrder_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.Desc(field.SortColumnName)
		}
	}

	var data model.ToyotaDeliveryOrder
	ok, err := session.Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}