// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/services/base/implments"
)

/******************************************************************************
 *
 * @Interface Name           : UserService
 *-----------------------------------------------------------------------------
 *
 * @Description              : User的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
type UserService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条User
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	InsertOne(*global.User, *model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的User
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	DeleteOne(*global.User, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的User
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	SelectOne(*global.User, string) (*model.User, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条User
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	UpdateOne(*global.User, *model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条User
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的User列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	Insert(*global.User, *[]model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条User
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的User列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	Delete(*global.User, *[]model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询User
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	Select(*global.User, map[string]string) ([]model.User, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询User
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-20 11:11:05
	 *
	 ******************************************************************************/
	SelectAndPaging(*global.User, map[string]string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条User
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的User列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	Update(*global.User, *[]model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : GetUserByUsername
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的User
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	GetUserByUsername(int, string) (*model.User, error)
	/******************************************************************************
	 *
	 * @Function Name            : SetPwd
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改密码
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	SetPwd(*global.User, *model.SysUserPwd) (bool, error)
	/******************************************************************************
	 *
	 * @Function Name            : GetUserInfo
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 获取用户信息
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	GetUserInfo(*global.User, string) (*model.UserViewInfo, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateStatus
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改状态
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	UpdateStatus(user *global.User, entity *model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdatePic
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改状态
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-08-16 16:11:14
	 *
	 ******************************************************************************/
	UpdatePic(user *global.User, entity *model.User) error
}

/******************************************************************************
 *
 * @Function Name            : NewUserService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个UserService
 *
 * @Return Value             : UserService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 16:11:14
 *
 ******************************************************************************/
func NewUserService() UserService {
	return implments.NewUserServiceImplement()
}
