// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package jit

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/jit"
	"LAPP_ACURA_MOM_BACKEND/services/jit/implments"
)

/******************************************************************************
 *
 * @Interface Name           : PackOrderService
 *-----------------------------------------------------------------------------
 *
 * @Description              : PackOrder的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
type PackOrderService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条PackOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的PackOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	InsertOne(*global.User, *model.PackOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的PackOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	DeleteOne(*global.User, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的PackOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的PackOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	SelectOne(*global.User, string) (*model.PackOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条PackOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的PackOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	UpdateOne(*global.User, *model.PackOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条PackOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的PackOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	Insert(*global.User, *[]model.PackOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条PackOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的PackOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	Delete(*global.User, *[]model.PackOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询PackOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	Select(*global.User, map[string]string) ([]model.PackOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询PackOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	SelectAndPaging(*global.User, map[string]string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条PackOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的PackOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	Update(*global.User, *[]model.PackOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : ScanBarcode
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 扫描包装单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 工单条码
	 *
	 * @Return Value             : *model.PackOrderInfo
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-10-22
	 *
	 ******************************************************************************/
	ScanBarcode(user *global.User, barcode string, workplaceNr int) (*model.PackOrderInfo, error)
	/******************************************************************************
	 *
	 * @Function Name            : ClosePackOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 关闭包装单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 包装单ID
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-12-16
	 *
	 ******************************************************************************/
	ClosePackOrder(user *global.User, packOrderId string) error
	/******************************************************************************
	 *
	 * @Function Name            : SplitPackOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 拆包
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 包装单ID
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-10-22
	 *
	 ******************************************************************************/
	SplitPackOrder(user *global.User, packOrderId string) error
	/******************************************************************************
	 *
	 * @Function Name            : SplitPackOrderBySerialOrderId
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 通过工单ID进行拆包
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 工单ID
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-12-16
	 *
	 ******************************************************************************/
	SplitPackOrderBySerialOrderId(user *global.User, serialOrderId string) error
	/******************************************************************************
	 *
	 * @Function Name            : GetUserOperatePackOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 获取用户当前操作的包装单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Return Value             : 包装单ID
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-12-16
	 *
	 ******************************************************************************/
	GetUserOperatePackOrder(user *global.User, location string) (string, error)
	// ScanBarcodeOutLine 线外打包
	ScanBarcodeOutLine(user *global.User, barcode string) (*model.PackOrderInfo, error)
	// RepairPlcErr 修复打包时plc写入的错误
	RepairPlcErr(user *global.User, packOrderId string) error
	ReadPLCBackFlushData(user *global.User)
	ReadPLCBackFlushDataTask()
}

/******************************************************************************
 *
 * @Function Name            : NewPackOrderService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PackOrderService
 *
 * @Return Value             : PackOrderService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func NewPackOrderService() PackOrderService {
	return implments.NewPackOrderServiceImplement()
}
