// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package jit

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/jit"
	"LAPP_ACURA_MOM_BACKEND/services/jit/implments"
)

/******************************************************************************
 *
 * @Interface Name           : ShipOrderService
 *-----------------------------------------------------------------------------
 *
 * @Description              : ShipOrder的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
type ShipOrderService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条ShipOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的ShipOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	InsertOne(*global.User, *model.ShipOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的ShipOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	DeleteOne(*global.User, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的ShipOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的ShipOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	SelectOne(*global.User, string) (*model.ShipOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条ShipOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的ShipOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	UpdateOne(*global.User, *model.ShipOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条ShipOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的ShipOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	Insert(*global.User, *[]model.ShipOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条ShipOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的ShipOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	Delete(*global.User, *[]model.ShipOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询ShipOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	Select(*global.User, map[string]string) ([]model.ShipOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询ShipOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	SelectAndPaging(*global.User, map[string]string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条ShipOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的ShipOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	Update(*global.User, *[]model.ShipOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : ChangeAdvanceToFormal
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 翻车 从预发运单转换成发运单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 预发运单ID
	*
	 * @Function Parameters      : 发运单ID
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-11-03
	 *
	 ******************************************************************************/
	ChangeAdvanceToFormal(user *global.User, advanceShipOrderId string, formalShipOrderId string) error
	/******************************************************************************
	 *
	 * @Function Name            : ScanBarCode
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 扫码 进行发运
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 工单条码
	*
	 * @Function Parameters      : 发运单ID
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-11-03
	 *
	 ******************************************************************************/
	ScanBarCode(user *global.User, barCode string, shipOrderId string, workPlaceNr int) (result *model.ShipResult, err error)
	/******************************************************************************
	 *
	 * @Function Name            : CreateAdvanceShipOrderByEdit
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 通过页面编辑创建发运单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 编辑的发运单
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-11-03
	 *
	 ******************************************************************************/
	CreateAdvanceShipOrderByEdit(user *global.User, shipOrder *model.ShipOrder) (err error)
	/******************************************************************************
	 *
	 * @Function Name            : CreateAdvanceShipOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 通过包装模板创建发运单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 模板ID
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-11-03
	 *
	 ******************************************************************************/
	CreateAdvanceShipOrder(user *global.User, shipTemplateId string, projectId string, plateNumber string, checkCarSet bool, planQty int) (err error)
	/******************************************************************************
	 *
	 * @Function Name            : CloseShipOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 关闭用户不是通过包装模板创建的预发运单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : shipOrderId
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-11-03
	 *
	 ******************************************************************************/
	CloseShipOrder(user *global.User, shipOrderId string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectWithStatus
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询ShipOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-10-19 10:26:40
	 *
	 ******************************************************************************/
	SelectWithStatus(user *global.User, urlParameters map[string]string) ([]model.ShipOrderWithStatus, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectShipDataBySerialOrderId
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 通过工单查询发运单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 工单
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2022-03-09
	 *
	 ******************************************************************************/
	SelectShipDataBySerialOrderId(user *global.User, serialOrderId string) ([]model.ShipOrderWithStatus, error)
	/******************************************************************************
	 *
	 * @Function Name            : WithdrawShipOrderItem
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 发运单子项回撤
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 发运单
	 *
	 * @Return Value             : 子项索引
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2022-03-11
	 *
	 ******************************************************************************/
	WithdrawShipOrderItem(user *global.User, shipOrderId string, pos int) error
	/******************************************************************************
	 *
	 * @Function Name            : CreateSpecialShipOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 创建特殊发运单
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2022-05-13
	 *
	 ******************************************************************************/
	CreateSpecialShipOrder(user *global.User) error
}

/******************************************************************************
 *
 * @Function Name            : NewShipOrderService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ShipOrderService
 *
 * @Return Value             : ShipOrderService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func NewShipOrderService() ShipOrderService {
	return implments.NewShipOrderServiceImplement()
}
