// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pln

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/pln"
	"LAPP_ACURA_MOM_BACKEND/services/pln/implments"
)

/******************************************************************************
 *
 * @Interface Name           : ToyotaTaskService
 *-----------------------------------------------------------------------------
 *
 * @Description              : ToyotaTask的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
type ToyotaTaskService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条ToyotaTask
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的ToyotaTask
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	InsertOne(*global.User, *model.ToyotaTask) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的ToyotaTask
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	DeleteOne(*global.User, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的ToyotaTask
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的ToyotaTask
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	SelectOne(*global.User, string) (*model.ToyotaTask, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条ToyotaTask
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的ToyotaTask
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	UpdateOne(*global.User, *model.ToyotaTask) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条ToyotaTask
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的ToyotaTask列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	Insert(*global.User, *[]model.ToyotaTask) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条ToyotaTask
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的ToyotaTask列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	Delete(*global.User, *[]model.ToyotaTask) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询ToyotaTask
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	Select(*global.User, map[string]string) ([]model.ToyotaTask, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询ToyotaTask
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	SelectAndPaging(*global.User, map[string]string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条ToyotaTask
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的ToyotaTask列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2022-07-12 13:58:15
	 *
	 ******************************************************************************/
	Update(*global.User, *[]model.ToyotaTask) error
}

/******************************************************************************
 *
 * @Function Name            : NewToyotaTaskService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ToyotaTaskService
 *
 * @Return Value             : ToyotaTaskService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func NewToyotaTaskService() ToyotaTaskService {
	return implments.NewToyotaTaskServiceImplement()
}
