// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package report

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	impl "LAPP_ACURA_MOM_BACKEND/services/report/implments"
	"time"
)

/******************************************************************************
 *
 * @Interface Name           : CustomizedQueryService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 定制查询服务接口
 *
 * @Author                   : chenglei.wei@le-it.com.cn
 *
 * @Date                     : 2022-03-08 17:50
 *
 ******************************************************************************/
type CustomizedQueryService interface {
	/******************************************************************************
	 *
	 * @Function Name            : ProductFamilyInventoryQuery
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 派生库存查询
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 派生号
	 *
	 * @Function Parameters      : 项目
	 *
	 * @Function Parameters      : 座椅条码
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-08 17:56
	 *
	 ******************************************************************************/
	ProductFamilyInventoryQuery(*global.User, string, string, string) ([]impl.ProductFamilyInventoryQuery_ProductFamilyStatistics, error)
	/******************************************************************************
	 *
	 * @Function Name            : ProductFamilyInventoryExportExcel
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 导出派生库存查询结果
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 派生号
	 *
	 * @Function Parameters      : 项目
	 *
	 * @Function Parameters      : 座椅条码
	 *
	 * @Return Value             : 导出文件路径
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-08 17:56
	 *
	 ******************************************************************************/
	ProductFamilyInventoryExportExcel(*global.User, string, string, string) (string, error)
	/******************************************************************************
	 *
	 * @Function Name            : SeatQuery
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 座椅查询
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 座椅条码
	 *
	 * @Function Parameters      : 状态（已打包、已目检）
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-08 17:58
	 *
	 ******************************************************************************/
	SeatQuery(*global.User, string, string) ([]impl.SeatQuery_SeatSummary, error)
	/******************************************************************************
	 *
	 * @Function Name            : SeatExportExcel
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 导出座椅查询结果
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 座椅条码
	 *
	 * @Function Parameters      : 状态（已打包、已目检）
	 *
	 * @Return Value             : 导出文件路径
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-08 17:58
	 *
	 ******************************************************************************/
	SeatExportExcel(*global.User, string, string) (string, error)
	/******************************************************************************
	 *
	 * @Function Name            : PackingRecordQuery
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 打包记录查询
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 工单条码
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-08 17:58
	 *
	 ******************************************************************************/
	PackingRecordQuery(*global.User, string) ([]impl.PackingRecordQuery_PackOrderSummary, error)
	/******************************************************************************
	 *
	 * @Function Name            : PackingRecordExportExcel
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 导出打包记录查询结果
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 工单条码
	 *
	 * @Return Value             : 导出文件路径
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-08 17:58
	 *
	 ******************************************************************************/
	PackingRecordExportExcel(*global.User, string) (string, error)
	/******************************************************************************
	 *
	 * @Function Name            : RepairQuery
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 不良统计分析
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 产线
	 *
	 * @Function Parameters      : 产品
	 *
	 * @Function Parameters      : 不良原因
	 *
	 * @Function Parameters      : 时间范围-开始
	 *
	 * @Function Parameters      : 时间范围-结束
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-15 10:19
	 *
	 ******************************************************************************/
	RepairQuery(*global.User, *grmi.Paging, string, string, string, *time.Time, *time.Time) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : RepairAnalysis_CountByDate
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 产品缺陷率分析
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 日期范围-开始
	 *
	 * @Function Parameters      : 日期范围-结束
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-15 10:19
	 *
	 ******************************************************************************/
	RepairAnalysis_CountByDate(*global.User, *time.Time, *time.Time) (impl.TableValues, error)
	/******************************************************************************
	 *
	 * @Function Name            : WorkLineDateReport
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 产线生产日报
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 产线
	 *
	 * @Function Parameters      : 日期范围-开始
	 *
	 * @Function Parameters      : 日期范围-结束
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-16 10:19
	 *
	 ******************************************************************************/
	WorkLineDateReport(*global.User, string, *time.Time, *time.Time) ([]impl.WorkLineDateReportItem, error)
	/******************************************************************************
	 *
	 * @Function Name            : WorkLineDateReport
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 导出产线生产日报
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 产线
	 *
	 * @Function Parameters      : 日期范围-开始
	 *
	 * @Function Parameters      : 日期范围-结束
	 *
	 * @Return Value             : 导出文件路径
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-16 16:22
	 *
	 ******************************************************************************/
	WorkLineDateReportExportExcel(*global.User, string, *time.Time, *time.Time) (string, error)
	/******************************************************************************
	 *
	 * @Function Name            : AndonAnalysis_CountByDate
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 生产异常统计分析
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 产线
	 *
	 * @Function Parameters      : 工位列表
	 *
	 * @Function Parameters      : 异常类型
	 *
	 * @Function Parameters      : 日期范围-开始
	 *
	 * @Function Parameters      : 日期范围-结束
	 *
	 * @Return Value             : 导出文件路径
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2022-03-17 10:08
	 *
	 ******************************************************************************/
	AndonAnalysis_CountByDate(*global.User, string, []string, string, *time.Time, *time.Time) (impl.TableValues, error)
}

/******************************************************************************
 *
 * @Function Name            : NewCustomizedQueryService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个CustomizedQueryService
 *
 * @Return Value             : CustomizedQueryService实例
 *
 * @Author                   : chenglei.wei@le-it.com.cn
 *
 * @Date                     : 2022-03-09 10:48
 *
 ******************************************************************************/
func NewCustomizedQueryService() CustomizedQueryService {
	return impl.NewCustomizedQueryServiceImplement()
}
