// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterOneArtQtyAllocate(party router.Party, httpMethod string, path string, method func(*global.User, *model.ArtQtyAllocate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtQtyAllocate)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterIDOfArtQtyAllocate(party router.Party, httpMethod string, path string, method func(*global.User, int, string, string, string, int, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		attriCode, err := ctx.Params().GetInt("attriCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineId := ctx.Params().GetString("workLineId")
		subObject := ctx.Params().GetString("subObject")
		projectId := ctx.Params().GetString("projectId")
		totalPlanty, err := ctx.Params().GetInt("totalPlanty")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pO := ctx.Params().GetString("pO")
		assignPlanty, err := ctx.Params().GetInt("assignPlanty")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, attriCode, workLineId, subObject, projectId, totalPlanty, pO, assignPlanty)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterInsertOneArtQtyAllocate(party router.Party, path string, method func(*global.User, *model.ArtQtyAllocate) error) {

	RegisterOneArtQtyAllocate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterDeleteOneArtQtyAllocate(party router.Party, path string, method func(*global.User, int, string, string, string, int, string, int) error) {

	RegisterIDOfArtQtyAllocate(party, "DELETE", path+"/{attriCode:int}/{workLineId:string}/{subObject:string}/{projectId:string}/{totalPlanty:int}/{pO:string}/{assignPlanty:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterSelectOneArtQtyAllocate(party router.Party, path string, method func(*global.User, int, string, string, string, int, string, int) (*model.ArtQtyAllocate, error)) {

	party.Get(path+"/{attriCode:int}/{workLineId:string}/{subObject:string}/{projectId:string}/{totalPlanty:int}/{pO:string}/{assignPlanty:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		attriCode, err := ctx.Params().GetInt("attriCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineId := ctx.Params().GetString("workLineId")
		subObject := ctx.Params().GetString("subObject")
		projectId := ctx.Params().GetString("projectId")
		totalPlanty, err := ctx.Params().GetInt("totalPlanty")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pO := ctx.Params().GetString("pO")
		assignPlanty, err := ctx.Params().GetInt("assignPlanty")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, attriCode, workLineId, subObject, projectId, totalPlanty, pO, assignPlanty)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterUpdateOneArtQtyAllocate(party router.Party, path string, method func(*global.User, *model.ArtQtyAllocate) error) {

	RegisterOneArtQtyAllocate(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterMultiArtQtyAllocate(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ArtQtyAllocate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArtQtyAllocate, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterInsertArtQtyAllocate(party router.Party, path string, method func(*global.User, *[]model.ArtQtyAllocate) error) {

	RegisterMultiArtQtyAllocate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterDeleteArtQtyAllocate(party router.Party, path string, method func(*global.User, *[]model.ArtQtyAllocate) error) {

	RegisterMultiArtQtyAllocate(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterSelectArtQtyAllocate(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ArtQtyAllocate, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArtQtyAllocate并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterQueryArtQtyAllocate(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 14:18:42
 *
 ******************************************************************************/
func RegisterUpdateArtQtyAllocate(party router.Party, path string, method func(*global.User, *[]model.ArtQtyAllocate) error) {

	RegisterMultiArtQtyAllocate(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArtCheckRuleByArt
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArtCheckRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-24 11:19:07
 *
 ******************************************************************************/
func RegisterSelectArtQtyAllocateByArt(party router.Party, path string, method func(*global.User, string, string) ([]model.ArtQtyAllocate, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		artId := ctx.URLParam("artId")
		projectId := ctx.URLParam("projectId")
		if artId == "" || projectId == "" {
			supports.Error(ctx, iris.StatusBadRequest, "参数错误", nil)
			return
		}
		result, err := method(user, artId, projectId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}