// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/utils"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"strings"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterOneArticle(party router.Party, httpMethod string, path string, method func(*global.User, *model.Article) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil

		entity := new(model.Article)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterIDOfArticle(party router.Party, httpMethod string, path string, method func(*global.User, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")
		projectId := ctx.Params().GetString("projectId")
		err = method(user, artId, projectId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertOneArticle(party router.Party, path string, method func(*global.User, *model.Article) error) {

	RegisterOneArticle(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteOneArticle(party router.Party, path string, method func(*global.User, string, string) error) {

	RegisterIDOfArticle(party, "DELETE", path+"/{artId:string}/{projectId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectOneArticle(party router.Party, path string, method func(*global.User, string, string) (*model.Article, error)) {

	party.Get(path+"/{artId:string}/{projectId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		artId := ctx.Params().GetString("artId")
		projectId := ctx.Params().GetString("projectId")
		result, err := method(user, artId, projectId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateOneArticle(party router.Party, path string, method func(*global.User, *model.Article) error) {

	RegisterOneArticle(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterMultiArticle(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.Article) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		entities := make([]model.Article, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertArticle(party router.Party, path string, method func(*global.User, *[]model.Article) error) {

	RegisterMultiArticle(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteArticle(party router.Party, path string, method func(*global.User, *[]model.Article) error) {

	RegisterMultiArticle(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectArticle(party router.Party, path string, method func(*global.User, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateArticle(party router.Party, path string, method func(*global.User, *[]model.Article) error) {

	RegisterMultiArticle(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArticleByWorkLineId
 *-----------------------------------------------------------------------------
 *
 * @Description              : 通过workLineId查询Article的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-10-08
 *
 ******************************************************************************/
func RegisterSelectArticleByWorkLineId(party router.Party, path string, method func(*global.User, string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workLineId := ctx.URLParam("workLineId")
		if workLineId == "" {
			supports.Error(ctx, iris.StatusBadRequest, "未获取到产线ID", nil)
			return
		}
		result, err := method(user, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArticleCols
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询Article指定列的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectArticleCols(party router.Party, path string, method func(*global.User, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterArticleUploadExcel
 *-----------------------------------------------------------------------------
 *
 * @Description              : excel导入数据
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-12-22
 *
 ******************************************************************************/
func RegisterArticleUploadExcel(party router.Party, path string, method func(*global.User, string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		var err error = nil
		_, info, err := ctx.FormFile("uploadfile")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, "获取上传文件出错,err: "+err.Error(), nil)
			return
		}

		guid := utils.MakeOrderSn("BASE")
		filenameLi := strings.Split(info.Filename, ".")
		filename := filenameLi[0]
		savePath := "web/public/uploadxlsx/" + filename + guid + ".xlsx"
		err = utils.SaveUploadedFile(info, savePath)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, "保存上传文件出错,err: "+err.Error(), nil)
			return
		}

		err = method(user, savePath)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterCopyArticle
 *-----------------------------------------------------------------------------
 *
 * @Description              : 复制
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2022-01-04
 *
 ******************************************************************************/
func RegisterCopyArticle(party router.Party, path string, method func(*global.User, string, string, string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		type Req struct {
			ArtId           string `json:"artId"`
			ProjectId       string `json:"projectId"`
			TargetProjectId string `json:"targetProjectId"`
		}
		var data Req
		if err := ctx.ReadJSON(&data); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, data.ArtId, data.ProjectId, data.TargetProjectId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
