// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterOneCrossPlanTaskDetail(party router.Party, httpMethod string, path string, method func(*global.User, *model.CrossPlanTaskDetail) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.CrossPlanTaskDetail)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterIDOfCrossPlanTaskDetail(party router.Party, httpMethod string, path string, method func(*global.User, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		taskNr, err := ctx.Params().GetInt("taskNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		itemNr, err := ctx.Params().GetInt("itemNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, taskNr, itemNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterInsertOneCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, *model.CrossPlanTaskDetail) error) {

	RegisterOneCrossPlanTaskDetail(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterDeleteOneCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, int, int) error) {

	RegisterIDOfCrossPlanTaskDetail(party, "DELETE", path+"/{taskNr:int}/{itemNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterSelectOneCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, int, int) (*model.CrossPlanTaskDetail, error)) {

	party.Get(path+"/{taskNr:int}/{itemNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		taskNr, err := ctx.Params().GetInt("taskNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		itemNr, err := ctx.Params().GetInt("itemNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, taskNr, itemNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterUpdateOneCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, *model.CrossPlanTaskDetail) error) {

	RegisterOneCrossPlanTaskDetail(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterMultiCrossPlanTaskDetail(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.CrossPlanTaskDetail) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.CrossPlanTaskDetail, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterInsertCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, *[]model.CrossPlanTaskDetail) error) {

	RegisterMultiCrossPlanTaskDetail(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterDeleteCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, *[]model.CrossPlanTaskDetail) error) {

	RegisterMultiCrossPlanTaskDetail(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterSelectCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, map[string]string) ([]model.CrossPlanTaskDetail, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CrossPlanTaskDetail并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterQueryCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateCrossPlanTaskDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条CrossPlanTaskDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-19 17:51:14
 *
 ******************************************************************************/
func RegisterUpdateCrossPlanTaskDetail(party router.Party, path string, method func(*global.User, *[]model.CrossPlanTaskDetail) error) {

	RegisterMultiCrossPlanTaskDetail(party, "PUT", path, method)
}
