// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterOneCrossPlanTaskHead(party router.Party, httpMethod string, path string, method func(*global.User, *model.CrossPlanTaskHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.CrossPlanTaskHead)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterIDOfCrossPlanTaskHead(party router.Party, httpMethod string, path string, method func(*global.User, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		taskNr, err := ctx.Params().GetInt("taskNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, taskNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterInsertOneCrossPlanTaskHead(party router.Party, path string, method func(*global.User, *model.CrossPlanTaskHead) error) {

	RegisterOneCrossPlanTaskHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterDeleteOneCrossPlanTaskHead(party router.Party, path string, method func(*global.User, int) error) {

	RegisterIDOfCrossPlanTaskHead(party, "DELETE", path+"/{taskNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterSelectOneCrossPlanTaskHead(party router.Party, path string, method func(*global.User, int) (*model.CrossPlanTaskHead, error)) {

	party.Get(path+"/{taskNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		taskNr, err := ctx.Params().GetInt("taskNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, taskNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterUpdateOneCrossPlanTaskHead(party router.Party, path string, method func(*global.User, *model.CrossPlanTaskHead) error) {

	RegisterOneCrossPlanTaskHead(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterMultiCrossPlanTaskHead(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.CrossPlanTaskHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.CrossPlanTaskHead, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterInsertCrossPlanTaskHead(party router.Party, path string, method func(*global.User, *[]model.CrossPlanTaskHead) error) {

	RegisterMultiCrossPlanTaskHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterDeleteCrossPlanTaskHead(party router.Party, path string, method func(*global.User, *[]model.CrossPlanTaskHead) error) {

	RegisterMultiCrossPlanTaskHead(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterSelectCrossPlanTaskHead(party router.Party, path string, method func(*global.User, map[string]string) ([]model.CrossPlanTaskHead, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CrossPlanTaskHead并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterQueryCrossPlanTaskHead(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条CrossPlanTaskHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterUpdateCrossPlanTaskHead(party router.Party, path string, method func(*global.User, *[]model.CrossPlanTaskHead) error) {

	RegisterMultiCrossPlanTaskHead(party, "PUT", path, method)
}




/******************************************************************************
 *
 * @Function Name            : RegisterQueryCrossPlanTaskHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CrossPlanTaskHead并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-05-20 09:04:14
 *
 ******************************************************************************/
func RegisterReloadTask(party router.Party, path string, method func(user *global.User) error) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		err := method(user)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
