// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterOneLabelTemplateDetail(party router.Party, httpMethod string, path string, method func(*global.User, *model.LabelTemplateDetail) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.LabelTemplateDetail)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterIDOfLabelTemplateDetail(party router.Party, httpMethod string, path string, method func(*global.User, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		labelTemplateId := ctx.Params().GetString("labelTemplateId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, labelTemplateId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterInsertOneLabelTemplateDetail(party router.Party, path string, method func(*global.User, *model.LabelTemplateDetail) error) {

	RegisterOneLabelTemplateDetail(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterDeleteOneLabelTemplateDetail(party router.Party, path string, method func(*global.User, string, int) error) {

	RegisterIDOfLabelTemplateDetail(party, "DELETE", path+"/{labelTemplateId:string}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterSelectOneLabelTemplateDetail(party router.Party, path string, method func(*global.User, string, int) (*model.LabelTemplateDetail, error)) {

	party.Get(path+"/{labelTemplateId:string}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		labelTemplateId := ctx.Params().GetString("labelTemplateId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, labelTemplateId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterUpdateOneLabelTemplateDetail(party router.Party, path string, method func(*global.User, *model.LabelTemplateDetail) error) {

	RegisterOneLabelTemplateDetail(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterMultiLabelTemplateDetail(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.LabelTemplateDetail) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.LabelTemplateDetail, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterInsertLabelTemplateDetail(party router.Party, path string, method func(*global.User, *[]model.LabelTemplateDetail) error) {

	RegisterMultiLabelTemplateDetail(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterDeleteLabelTemplateDetail(party router.Party, path string, method func(*global.User, *[]model.LabelTemplateDetail) error) {

	RegisterMultiLabelTemplateDetail(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterSelectLabelTemplateDetail(party router.Party, path string, method func(*global.User, map[string]string) ([]model.LabelTemplateDetail, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询LabelTemplateDetail并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterQueryLabelTemplateDetail(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateLabelTemplateDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条LabelTemplateDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterUpdateLabelTemplateDetail(party router.Party, path string, method func(*global.User, *[]model.LabelTemplateDetail) error) {

	RegisterMultiLabelTemplateDetail(party, "PUT", path, method)
}
