// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterOneLabelTemplateHead(party router.Party, httpMethod string, path string, method func(*global.User, *model.LabelTemplateHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.LabelTemplateHead)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterIDOfLabelTemplateHead(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		labelTemplateId := ctx.Params().GetString("labelTemplateId")

		err = method(user, labelTemplateId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterInsertOneLabelTemplateHead(party router.Party, path string, method func(*global.User, *model.LabelTemplateHead) error) {

	RegisterOneLabelTemplateHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterDeleteOneLabelTemplateHead(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfLabelTemplateHead(party, "DELETE", path+"/{labelTemplateId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterSelectOneLabelTemplateHead(party router.Party, path string, method func(*global.User, string) (*model.LabelTemplateHead, error)) {

	party.Get(path+"/{labelTemplateId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		labelTemplateId := ctx.Params().GetString("labelTemplateId")
		result, err := method(user, labelTemplateId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterUpdateOneLabelTemplateHead(party router.Party, path string, method func(*global.User, *model.LabelTemplateHead) error) {

	RegisterOneLabelTemplateHead(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterMultiLabelTemplateHead(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.LabelTemplateHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.LabelTemplateHead, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterInsertLabelTemplateHead(party router.Party, path string, method func(*global.User, *[]model.LabelTemplateHead) error) {

	RegisterMultiLabelTemplateHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterDeleteLabelTemplateHead(party router.Party, path string, method func(*global.User, *[]model.LabelTemplateHead) error) {

	RegisterMultiLabelTemplateHead(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterSelectLabelTemplateHead(party router.Party, path string, method func(*global.User, map[string]string) ([]model.LabelTemplateHead, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询LabelTemplateHead并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterQueryLabelTemplateHead(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateLabelTemplateHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条LabelTemplateHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 16:19:35
 *
 ******************************************************************************/
func RegisterUpdateLabelTemplateHead(party router.Party, path string, method func(*global.User, *[]model.LabelTemplateHead) error) {

	RegisterMultiLabelTemplateHead(party, "PUT", path, method)
}
