// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterOneMaterialFrameInfo(party router.Party, httpMethod string, path string, method func(*global.User, *model.MaterialFrameInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.MaterialFrameInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterIDOfMaterialFrameInfo(party router.Party, httpMethod string, path string, method func(*global.User, int, string, string, string, int, int, int, string, string, string, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceDesc := ctx.Params().GetString("workPlaceDesc")
		gatewayIP := ctx.Params().GetString("gatewayIP")
		lampAddress := ctx.Params().GetString("lampAddress")
		frameID, err := ctx.Params().GetInt("frameID")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		levelID, err := ctx.Params().GetInt("levelID")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		boxID, err := ctx.Params().GetInt("boxID")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		tagAddr := ctx.Params().GetString("tagAddr")
		artID := ctx.Params().GetString("artID")
		custArtID := ctx.Params().GetString("custArtID")
		descCN := ctx.Params().GetString("descCN")
		standardPack, err := ctx.Params().GetInt("standardPack")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, workPlaceNr, workPlaceDesc, gatewayIP, lampAddress, frameID, levelID, boxID, tagAddr, artID, custArtID, descCN, standardPack)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterInsertOneMaterialFrameInfo(party router.Party, path string, method func(*global.User, *model.MaterialFrameInfo) error) {

	RegisterOneMaterialFrameInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterDeleteOneMaterialFrameInfo(party router.Party, path string, method func(*global.User, int, string, string, string, int, int, int, string, string, string, string, int) error) {

	RegisterIDOfMaterialFrameInfo(party, "DELETE", path+"/{workPlaceNr:int}/{workPlaceDesc:string}/{gatewayIP:string}/{lampAddress:string}/{frameID:int}/{levelID:int}/{boxID:int}/{tagAddr:string}/{artID:string}/{custArtID:string}/{descCN:string}/{standardPack:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterSelectOneMaterialFrameInfo(party router.Party, path string, method func(*global.User, int, string, string, string, int, int, int, string, string, string, string, int) (*model.MaterialFrameInfo, error)) {

	party.Get(path+"/{workPlaceNr:int}/{workPlaceDesc:string}/{gatewayIP:string}/{lampAddress:string}/{frameID:int}/{levelID:int}/{boxID:int}/{tagAddr:string}/{artID:string}/{custArtID:string}/{descCN:string}/{standardPack:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceDesc := ctx.Params().GetString("workPlaceDesc")
		gatewayIP := ctx.Params().GetString("gatewayIP")
		lampAddress := ctx.Params().GetString("lampAddress")
		frameID, err := ctx.Params().GetInt("frameID")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		levelID, err := ctx.Params().GetInt("levelID")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		boxID, err := ctx.Params().GetInt("boxID")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		tagAddr := ctx.Params().GetString("tagAddr")
		artID := ctx.Params().GetString("artID")
		custArtID := ctx.Params().GetString("custArtID")
		descCN := ctx.Params().GetString("descCN")
		standardPack, err := ctx.Params().GetInt("standardPack")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, workPlaceNr, workPlaceDesc, gatewayIP, lampAddress, frameID, levelID, boxID, tagAddr, artID, custArtID, descCN, standardPack)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterUpdateOneMaterialFrameInfo(party router.Party, path string, method func(*global.User, *model.MaterialFrameInfo) error) {

	RegisterOneMaterialFrameInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterMultiMaterialFrameInfo(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.MaterialFrameInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.MaterialFrameInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterInsertMaterialFrameInfo(party router.Party, path string, method func(*global.User, *[]model.MaterialFrameInfo) error) {

	RegisterMultiMaterialFrameInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterDeleteMaterialFrameInfo(party router.Party, path string, method func(*global.User, *[]model.MaterialFrameInfo) error) {

	RegisterMultiMaterialFrameInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterSelectMaterialFrameInfo(party router.Party, path string, method func(*global.User, map[string]string) ([]model.MaterialFrameInfo, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询MaterialFrameInfo并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterQueryMaterialFrameInfo(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateMaterialFrameInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-19 16:19:33
 *
 ******************************************************************************/
func RegisterUpdateMaterialFrameInfo(party router.Party, path string, method func(*global.User, *[]model.MaterialFrameInfo) error) {

	RegisterMultiMaterialFrameInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateMaterialFrameInfoData
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个更新MaterialFrameInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-11-22
 *
 ******************************************************************************/
func RegisterUpdateMaterialFrameInfoData(party router.Party, path string, method func(*global.User, *model.MaterialFrameInfo) error) {

	party.Put(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var entity model.MaterialFrameInfo
		if err := ctx.ReadJSON(&entity); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, &entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}