// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterOneOPCComValueCheckRuleDetail(party router.Party, httpMethod string, path string, method func(*global.User, *model.OPCComValueCheckRuleDetail) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil

		entity := new(model.OPCComValueCheckRuleDetail)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterIDOfOPCComValueCheckRuleDetail(party router.Party, httpMethod string, path string, method func(*global.User, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil
		id, err := ctx.Params().GetInt("id")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		detailId, err := ctx.Params().GetInt("detailId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, id, detailId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterInsertOneOPCComValueCheckRuleDetail(party router.Party, path string, method func(*global.User, *model.OPCComValueCheckRuleDetail) error) {

	RegisterOneOPCComValueCheckRuleDetail(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterDeleteOneOPCComValueCheckRuleDetail(party router.Party, path string, method func(*global.User, int, int) error) {

	RegisterIDOfOPCComValueCheckRuleDetail(party, "DELETE", path+"/{id:int}/{detailId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterSelectOneOPCComValueCheckRuleDetail(party router.Party, path string, method func(*global.User, int, int) (*model.OPCComValueCheckRuleDetail, error)) {

	party.Get(path+"/{id:int}/{detailId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		id, err := ctx.Params().GetInt("id")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		detailId, err := ctx.Params().GetInt("detailId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, id, detailId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterUpdateOneOPCComValueCheckRuleDetail(party router.Party, path string, method func(*global.User, *model.OPCComValueCheckRuleDetail) error) {

	RegisterOneOPCComValueCheckRuleDetail(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterMultiOPCComValueCheckRuleDetail(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.OPCComValueCheckRuleDetail) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		entities := make([]model.OPCComValueCheckRuleDetail, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterInsertOPCComValueCheckRuleDetail(party router.Party, path string, method func(*global.User, *[]model.OPCComValueCheckRuleDetail) error) {

	RegisterMultiOPCComValueCheckRuleDetail(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterDeleteOPCComValueCheckRuleDetail(party router.Party, path string, method func(*global.User, *[]model.OPCComValueCheckRuleDetail) error) {

	RegisterMultiOPCComValueCheckRuleDetail(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterSelectOPCComValueCheckRuleDetail(party router.Party, path string, method func(*global.User, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOPCComValueCheckRuleDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条OPCComValueCheckRuleDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-09-09 10:59:52
 *
 ******************************************************************************/
func RegisterUpdateOPCComValueCheckRuleDetail(party router.Party, path string, method func(*global.User, *[]model.OPCComValueCheckRuleDetail) error) {

	RegisterMultiOPCComValueCheckRuleDetail(party, "PUT", path, method)
}
