// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterOneOPCMonitorComRule(party router.Party, httpMethod string, path string, method func(*global.User, *model.OPCMonitorComRule) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.OPCMonitorComRule)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterIDOfOPCMonitorComRule(party router.Party, httpMethod string, path string, method func(*global.User, int, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		ruleId, err := ctx.Params().GetInt("ruleId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, operationId, workPlaceNr, ruleId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterInsertOneOPCMonitorComRule(party router.Party, path string, method func(*global.User, *model.OPCMonitorComRule) error) {

	RegisterOneOPCMonitorComRule(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterDeleteOneOPCMonitorComRule(party router.Party, path string, method func(*global.User, int, int, int) error) {

	RegisterIDOfOPCMonitorComRule(party, "DELETE", path+"/{operationId:int}/{workPlaceNr:int}/{ruleId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterSelectOneOPCMonitorComRule(party router.Party, path string, method func(*global.User, int, int, int) (*model.OPCMonitorComRule, error)) {

	party.Get(path+"/{operationId:int}/{workPlaceNr:int}/{ruleId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		ruleId, err := ctx.Params().GetInt("ruleId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, operationId, workPlaceNr, ruleId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterUpdateOneOPCMonitorComRule(party router.Party, path string, method func(*global.User, *model.OPCMonitorComRule) error) {

	RegisterOneOPCMonitorComRule(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterMultiOPCMonitorComRule(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.OPCMonitorComRule) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.OPCMonitorComRule, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterInsertOPCMonitorComRule(party router.Party, path string, method func(*global.User, *[]model.OPCMonitorComRule) error) {

	RegisterMultiOPCMonitorComRule(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterDeleteOPCMonitorComRule(party router.Party, path string, method func(*global.User, *[]model.OPCMonitorComRule) error) {

	RegisterMultiOPCMonitorComRule(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterSelectOPCMonitorComRule(party router.Party, path string, method func(*global.User, map[string]string) ([]model.OPCMonitorComRule, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询OPCMonitorComRule并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterQueryOPCMonitorComRule(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOPCMonitorComRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条OPCMonitorComRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-25 09:48:01
 *
 ******************************************************************************/
func RegisterUpdateOPCMonitorComRule(party router.Party, path string, method func(*global.User, *[]model.OPCMonitorComRule) error) {

	RegisterMultiOPCMonitorComRule(party, "PUT", path, method)
}
