// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterOnePLCErrorInfo(party router.Party, httpMethod string, path string, method func(*global.User, *model.PLCErrorInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.PLCErrorInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterIDOfPLCErrorInfo(party router.Party, httpMethod string, path string, method func(*global.User, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		errorId := ctx.Params().GetString("errorId")
		source := ctx.Params().GetString("source")

		err = method(user, errorId, source)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterInsertOnePLCErrorInfo(party router.Party, path string, method func(*global.User, *model.PLCErrorInfo) error) {

	RegisterOnePLCErrorInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterDeleteOnePLCErrorInfo(party router.Party, path string, method func(*global.User, string, string) error) {

	RegisterIDOfPLCErrorInfo(party, "DELETE", path+"/{errorId:string}/{source:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterSelectOnePLCErrorInfo(party router.Party, path string, method func(*global.User, string, string) (*model.PLCErrorInfo, error)) {

	party.Get(path+"/{errorId:string}/{source:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		errorId := ctx.Params().GetString("errorId")
		source := ctx.Params().GetString("source")
		result, err := method(user, errorId, source)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterUpdateOnePLCErrorInfo(party router.Party, path string, method func(*global.User, *model.PLCErrorInfo) error) {

	RegisterOnePLCErrorInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterMultiPLCErrorInfo(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.PLCErrorInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.PLCErrorInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterInsertPLCErrorInfo(party router.Party, path string, method func(*global.User, *[]model.PLCErrorInfo) error) {

	RegisterMultiPLCErrorInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterDeletePLCErrorInfo(party router.Party, path string, method func(*global.User, *[]model.PLCErrorInfo) error) {

	RegisterMultiPLCErrorInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterSelectPLCErrorInfo(party router.Party, path string, method func(*global.User, map[string]string) ([]model.PLCErrorInfo, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryPLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PLCErrorInfo并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterQueryPLCErrorInfo(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePLCErrorInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条PLCErrorInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-14 17:25:00
 *
 ******************************************************************************/
func RegisterUpdatePLCErrorInfo(party router.Party, path string, method func(*global.User, *[]model.PLCErrorInfo) error) {

	RegisterMultiPLCErrorInfo(party, "PUT", path, method)
}
