// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterOnePrintBasicRuleInfo(party router.Party, httpMethod string, path string, method func(*global.User, *model.PrintBasicRuleInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.PrintBasicRuleInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterIDOfPrintBasicRuleInfo(party router.Party, httpMethod string, path string, method func(*global.User, int, int, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		mainCodeName := ctx.Params().GetString("mainCodeName")
		templateFile := ctx.Params().GetString("templateFile")

		err = method(user, operationId, workPlaceNr, mainCodeName, templateFile)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterInsertOnePrintBasicRuleInfo(party router.Party, path string, method func(*global.User, *model.PrintBasicRuleInfo) error) {

	RegisterOnePrintBasicRuleInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterDeleteOnePrintBasicRuleInfo(party router.Party, path string, method func(*global.User, int, int, string, string) error) {

	RegisterIDOfPrintBasicRuleInfo(party, "DELETE", path+"/{operationId:int}/{workPlaceNr:int}/{mainCodeName:string}/{templateFile:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterSelectOnePrintBasicRuleInfo(party router.Party, path string, method func(*global.User, int, int, string, string) (*model.PrintBasicRuleInfo, error)) {

	party.Get(path+"/{operationId:int}/{workPlaceNr:int}/{mainCodeName:string}/{templateFile:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		mainCodeName := ctx.Params().GetString("mainCodeName")
		templateFile := ctx.Params().GetString("templateFile")
		result, err := method(user, operationId, workPlaceNr, mainCodeName, templateFile)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterUpdateOnePrintBasicRuleInfo(party router.Party, path string, method func(*global.User, *model.PrintBasicRuleInfo) error) {

	RegisterOnePrintBasicRuleInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterMultiPrintBasicRuleInfo(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.PrintBasicRuleInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.PrintBasicRuleInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterInsertPrintBasicRuleInfo(party router.Party, path string, method func(*global.User, *[]model.PrintBasicRuleInfo) error) {

	RegisterMultiPrintBasicRuleInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterDeletePrintBasicRuleInfo(party router.Party, path string, method func(*global.User, *[]model.PrintBasicRuleInfo) error) {

	RegisterMultiPrintBasicRuleInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterSelectPrintBasicRuleInfo(party router.Party, path string, method func(*global.User, map[string]string) ([]model.PrintBasicRuleInfo, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryPrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PrintBasicRuleInfo并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterQueryPrintBasicRuleInfo(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePrintBasicRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条PrintBasicRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-01 11:23:29
 *
 ******************************************************************************/
func RegisterUpdatePrintBasicRuleInfo(party router.Party, path string, method func(*global.User, *[]model.PrintBasicRuleInfo) error) {

	RegisterMultiPrintBasicRuleInfo(party, "PUT", path, method)
}
