// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterOneRoleMenu(party router.Party, httpMethod string, path string, method func(*global.User, *model.RoleMenu) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil

		entity := new(model.RoleMenu)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterIDOfRoleMenu(party router.Party, httpMethod string, path string, method func(*global.User, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil
		roleId, err := ctx.Params().GetInt("roleId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		menuId, err := ctx.Params().GetInt("menuId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, roleId, menuId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterInsertOneRoleMenu(party router.Party, path string, method func(*global.User, *model.RoleMenu) error) {

	RegisterOneRoleMenu(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterDeleteOneRoleMenu(party router.Party, path string, method func(*global.User, int, int) error) {

	RegisterIDOfRoleMenu(party, "DELETE", path+"/{roleId:int}/{menuId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterSelectOneRoleMenu(party router.Party, path string, method func(*global.User, int, int) (*model.RoleMenu, error)) {

	party.Get(path+"/{roleId:int}/{menuId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		roleId, err := ctx.Params().GetInt("roleId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		menuId, err := ctx.Params().GetInt("menuId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, roleId, menuId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterUpdateOneRoleMenu(party router.Party, path string, method func(*global.User, *model.RoleMenu) error) {

	RegisterOneRoleMenu(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterMultiRoleMenu(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.RoleMenu) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		entities := make([]model.RoleMenu, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterInsertRoleMenu(party router.Party, path string, method func(*global.User, *[]model.RoleMenu) error) {

	RegisterMultiRoleMenu(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterDeleteRoleMenu(party router.Party, path string, method func(*global.User, *[]model.RoleMenu) error) {

	RegisterMultiRoleMenu(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterSelectRoleMenu(party router.Party, path string, method func(*global.User, map[string]string) ([]model.RoleMenu, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询RoleMenu并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterQueryRoleMenu(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateRoleMenu
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条RoleMenu的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-20 11:11:05
 *
 ******************************************************************************/
func RegisterUpdateRoleMenu(party router.Party, path string, method func(*global.User, *[]model.RoleMenu) error) {

	RegisterMultiRoleMenu(party, "PUT", path, method)
}
