// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterOneScanRuleInfo(party router.Party, httpMethod string, path string, method func(*global.User, *model.ScanRuleInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ScanRuleInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterIDOfScanRuleInfo(party router.Party, httpMethod string, path string, method func(*global.User, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, operationId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterInsertOneScanRuleInfo(party router.Party, path string, method func(*global.User, *model.ScanRuleInfo) error) {

	RegisterOneScanRuleInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterDeleteOneScanRuleInfo(party router.Party, path string, method func(*global.User, int) error) {

	RegisterIDOfScanRuleInfo(party, "DELETE", path+"/{operationId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterSelectOneScanRuleInfo(party router.Party, path string, method func(*global.User, int) (*model.ScanRuleInfo, error)) {

	party.Get(path+"/{operationId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, operationId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterUpdateOneScanRuleInfo(party router.Party, path string, method func(*global.User, *model.ScanRuleInfo) error) {

	RegisterOneScanRuleInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterMultiScanRuleInfo(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ScanRuleInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ScanRuleInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterInsertScanRuleInfo(party router.Party, path string, method func(*global.User, *[]model.ScanRuleInfo) error) {

	RegisterMultiScanRuleInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterDeleteScanRuleInfo(party router.Party, path string, method func(*global.User, *[]model.ScanRuleInfo) error) {

	RegisterMultiScanRuleInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterSelectScanRuleInfo(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ScanRuleInfo, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ScanRuleInfo并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterQueryScanRuleInfo(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateScanRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ScanRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-23 11:13:02
 *
 ******************************************************************************/
func RegisterUpdateScanRuleInfo(party router.Party, path string, method func(*global.User, *[]model.ScanRuleInfo) error) {

	RegisterMultiScanRuleInfo(party, "PUT", path, method)
}
