// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/base"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterOneSnrOccupy(party router.Party, httpMethod string, path string, method func(*global.User, *model.SnrOccupy) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.SnrOccupy)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterIDOfSnrOccupy(party router.Party, httpMethod string, path string, method func(*global.User, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		occupyNr, err := ctx.Params().GetInt("occupyNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, occupyNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterInsertOneSnrOccupy(party router.Party, path string, method func(*global.User, *model.SnrOccupy) error) {

	RegisterOneSnrOccupy(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterDeleteOneSnrOccupy(party router.Party, path string, method func(*global.User, int) error) {

	RegisterIDOfSnrOccupy(party, "DELETE", path+"/{occupyNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterSelectOneSnrOccupy(party router.Party, path string, method func(*global.User, int) (*model.SnrOccupy, error)) {

	party.Get(path+"/{occupyNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		occupyNr, err := ctx.Params().GetInt("occupyNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, occupyNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterUpdateOneSnrOccupy(party router.Party, path string, method func(*global.User, *model.SnrOccupy) error) {

	RegisterOneSnrOccupy(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterMultiSnrOccupy(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.SnrOccupy) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.SnrOccupy, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterInsertSnrOccupy(party router.Party, path string, method func(*global.User, *[]model.SnrOccupy) error) {

	RegisterMultiSnrOccupy(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterDeleteSnrOccupy(party router.Party, path string, method func(*global.User, *[]model.SnrOccupy) error) {

	RegisterMultiSnrOccupy(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterSelectSnrOccupy(party router.Party, path string, method func(*global.User, map[string]string) ([]model.SnrOccupy, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQuerySnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询SnrOccupy并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterQuerySnrOccupy(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateSnrOccupy
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条SnrOccupy的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-22 11:26:46
 *
 ******************************************************************************/
func RegisterUpdateSnrOccupy(party router.Party, path string, method func(*global.User, *[]model.SnrOccupy) error) {

	RegisterMultiSnrOccupy(party, "PUT", path, method)
}
