// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package jit

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/jit"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterOneShipOrder(party router.Party, httpMethod string, path string, method func(*global.User, *model.ShipOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil

		entity := new(model.ShipOrder)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterIDOfShipOrder(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil
		shipOrderId := ctx.Params().GetString("shipOrderId")

		err = method(user, shipOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterInsertOneShipOrder(party router.Party, path string, method func(*global.User, *model.ShipOrder) error) {

	RegisterOneShipOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterDeleteOneShipOrder(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfShipOrder(party, "DELETE", path+"/{shipOrderId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterSelectOneShipOrder(party router.Party, path string, method func(*global.User, string) (*model.ShipOrder, error)) {

	party.Get(path+"/{shipOrderId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		shipOrderId := ctx.Params().GetString("shipOrderId")
		result, err := method(user, shipOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterUpdateOneShipOrder(party router.Party, path string, method func(*global.User, *model.ShipOrder) error) {

	RegisterOneShipOrder(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterMultiShipOrder(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ShipOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		entities := make([]model.ShipOrder, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterInsertShipOrder(party router.Party, path string, method func(*global.User, *[]model.ShipOrder) error) {

	RegisterMultiShipOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterDeleteShipOrder(party router.Party, path string, method func(*global.User, *[]model.ShipOrder) error) {

	RegisterMultiShipOrder(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterSelectShipOrder(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ShipOrder, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrder并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterQueryShipOrder(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterUpdateShipOrder(party router.Party, path string, method func(*global.User, *[]model.ShipOrder) error) {

	RegisterMultiShipOrder(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterCreateAdvanceShipOrderByTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过模板创建发运单的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-03
 *
 ******************************************************************************/
func RegisterCreateAdvanceShipOrder(party router.Party, path string, method func(user *global.User, shipTemplateId string, projectId string, plateNumber string, checkCarSet bool, planQty int) (err error)) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		type Req struct {
			ShipTemplateId string `json:"shipTemplateId"`
			ProjectId string `json:"projectId"`
			PlateNumber string `json:"plateNumber"`
			CheckCarSet bool `json:"checkCarSet"`
			PlanQty int `json:"planQty"`
		}
		var data Req
		if err := ctx.ReadJSON(&data); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if data.ShipTemplateId == "" && data.ProjectId == "" {
			supports.Error(ctx, iris.StatusBadRequest, "参数为空", nil)
			return
		}
		err := method(user, data.ShipTemplateId, data.ProjectId, data.PlateNumber, data.CheckCarSet, data.PlanQty)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}


/******************************************************************************
 *
 * @Function Name            : RegisterCreateAdvanceShipOrderByEdit
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个页面编辑创建包装单的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-11-03
 *
 ******************************************************************************/
func RegisterCreateAdvanceShipOrderByEdit(party router.Party, path string, method func(user *global.User, shipOrder *model.ShipOrder) (err error)) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		var entity model.ShipOrder
		if err := ctx.ReadJSON(&entity); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, &entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterScanBarCode
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个扫描包装单中工单条码的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-11-03
 *
 ******************************************************************************/
func RegisterScanBarCode(party router.Party, path string, method func(user *global.User, barCode string, shipOrderId string, workPlaceNr int) (result *model.ShipResult, err error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		barcode := ctx.URLParam("barcode")
		shipOrderId := ctx.URLParam("shipOrderId")
		workPlaceNr, err := ctx.URLParamInt("workPlaceNr")
		if err != nil {
			workPlaceNr = 0
		}
		result, err := method(user, barcode, shipOrderId, workPlaceNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterChangeAdvanceToFormal
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个翻车的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-11-03
 *
 ******************************************************************************/
func RegisterChangeAdvanceToFormal(party router.Party, path string, method func(user *global.User, advanceShipOrderId string, formalShipOrderId string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		type Req struct {
			AdvanceShipOrderId string `json:"advanceShipOrderId"`
			FormalShipOrderId string `json:"formalShipOrderId"`
		}
		var data Req
		if err := ctx.ReadJSON(&data); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, data.AdvanceShipOrderId, data.FormalShipOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterChangeAdvanceToFormal
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个翻车的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-11-03
 *
 ******************************************************************************/
func RegisterCloseShipOrder(party router.Party, path string, method func(user *global.User, shipOrderId string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		type Req struct {
			ShipOrderId string `json:"shipOrderId"`
		}
		var data Req
		if err := ctx.ReadJSON(&data); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, data.ShipOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectShipOrderWithStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterSelectShipOrderWithStatus(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ShipOrderWithStatus, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectShipOrderBySerialOrderId
 *-----------------------------------------------------------------------------
 *
 * @Description              : 通过工单查询发运单
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2022-03-09
 *
 ******************************************************************************/
func RegisterSelectShipOrderBySerialOrderId(party router.Party, path string, method func(*global.User, string) ([]model.ShipOrderWithStatus, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		serialOrderId := ctx.URLParam("serialOrderId")
		if serialOrderId == "" {
			supports.Error(ctx, iris.StatusBadRequest, "未获取到工单条码", nil)
			return
		}
		result, err := method(user, serialOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
*
* @Function Name            : RegisterSelectShipOrderBySerialOrderId
*-----------------------------------------------------------------------------
*
* @Description              : 通过工单查询发运单
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : zhangxin
*
* @Date                     : 2022-03-09
*
******************************************************************************/
func RegisterWithdrawShipOrderItem(party router.Party, path string, method func(user *global.User, shipOrderId string, pos int) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		type Req struct {
			ShipOrderId string `json:"shipOrderId"`
			Pos int `json:"pos"`
		}
		var data Req
		if err := ctx.ReadJSON(&data); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if data.ShipOrderId == "" || data.Pos == 0 {
			supports.Error(ctx, iris.StatusBadRequest, "参数错误", nil)
			return
		}
		err := method(user, data.ShipOrderId, data.Pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}



/******************************************************************************
*
* @Function Name            : RegisterCreateSpecialShipOrder
*-----------------------------------------------------------------------------
*
* @Description              : 创建特殊发运单
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : zhangxin
*
* @Date                     : 2022-05-13
*
******************************************************************************/
func RegisterCreateSpecialShipOrder(party router.Party, path string, method func(user *global.User) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		err := method(user)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}