// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package jit

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/jit"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterOneShipOrderStatus(party router.Party, httpMethod string, path string, method func(*global.User, *model.ShipOrderStatus) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil

		entity := new(model.ShipOrderStatus)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterIDOfShipOrderStatus(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var err error = nil
		shipOrderId := ctx.Params().GetString("shipOrderId")

		err = method(user, shipOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterInsertOneShipOrderStatus(party router.Party, path string, method func(*global.User, *model.ShipOrderStatus) error) {

	RegisterOneShipOrderStatus(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterDeleteOneShipOrderStatus(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfShipOrderStatus(party, "DELETE", path+"/{shipOrderId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterSelectOneShipOrderStatus(party router.Party, path string, method func(*global.User, string) (*model.ShipOrderStatus, error)) {

	party.Get(path+"/{shipOrderId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		shipOrderId := ctx.Params().GetString("shipOrderId")
		result, err := method(user, shipOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterUpdateOneShipOrderStatus(party router.Party, path string, method func(*global.User, *model.ShipOrderStatus) error) {

	RegisterOneShipOrderStatus(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterMultiShipOrderStatus(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ShipOrderStatus) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		entities := make([]model.ShipOrderStatus, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterInsertShipOrderStatus(party router.Party, path string, method func(*global.User, *[]model.ShipOrderStatus) error) {

	RegisterMultiShipOrderStatus(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterDeleteShipOrderStatus(party router.Party, path string, method func(*global.User, *[]model.ShipOrderStatus) error) {

	RegisterMultiShipOrderStatus(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterSelectShipOrderStatus(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ShipOrderStatus, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrderStatus并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterQueryShipOrderStatus(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateShipOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ShipOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-19 10:26:40
 *
 ******************************************************************************/
func RegisterUpdateShipOrderStatus(party router.Party, path string, method func(*global.User, *[]model.ShipOrderStatus) error) {

	RegisterMultiShipOrderStatus(party, "PUT", path, method)
}
