// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package me

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/me"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterOneProductFamilyWorkLineLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProductFamilyWorkLineLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProductFamilyWorkLineLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterIDOfProductFamilyWorkLineLst(party router.Party, httpMethod string, path string, method func(*global.User, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		productFamilyId := ctx.Params().GetString("productFamilyId")
		workLineId := ctx.Params().GetString("workLineId")

		err = method(user, productFamilyId, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterInsertOneProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, *model.ProductFamilyWorkLineLst) error) {

	RegisterOneProductFamilyWorkLineLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterDeleteOneProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, string, string) error) {

	RegisterIDOfProductFamilyWorkLineLst(party, "DELETE", path+"/{productFamilyId:string}/{workLineId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterSelectOneProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, string, string) (*model.ProductFamilyWorkLineLst, error)) {

	party.Get(path+"/{productFamilyId:string}/{workLineId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		productFamilyId := ctx.Params().GetString("productFamilyId")
		workLineId := ctx.Params().GetString("workLineId")
		result, err := method(user, productFamilyId, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterUpdateOneProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, *model.ProductFamilyWorkLineLst) error) {

	RegisterOneProductFamilyWorkLineLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterMultiProductFamilyWorkLineLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProductFamilyWorkLineLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProductFamilyWorkLineLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterInsertProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, *[]model.ProductFamilyWorkLineLst) error) {

	RegisterMultiProductFamilyWorkLineLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterDeleteProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, *[]model.ProductFamilyWorkLineLst) error) {

	RegisterMultiProductFamilyWorkLineLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterSelectProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProductFamilyWorkLineLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProductFamilyWorkLineLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterQueryProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProductFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterUpdateProductFamilyWorkLineLst(party router.Party, path string, method func(*global.User, *[]model.ProductFamilyWorkLineLst) error) {

	RegisterMultiProductFamilyWorkLineLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSaveFamilyWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个保存ProductFamilyWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-04-11 13:56:25
 *
 ******************************************************************************/
func RegisterSaveFamilyWorkLineLst(party router.Party, path string, method func(*global.User, *model.ProductFamilyWorkLineData) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		var entity model.ProductFamilyWorkLineData
		var err error
		if err = ctx.ReadJSON(&entity); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err = method(user, &entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
