// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package me

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/me"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterOneProductWorkLineLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.ProductWorkLineLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProductWorkLineLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterIDOfProductWorkLineLst(party router.Party, httpMethod string, path string, method func(*global.User, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		productId := ctx.Params().GetString("productId")
		workLineId := ctx.Params().GetString("workLineId")

		err = method(user, productId, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterInsertOneProductWorkLineLst(party router.Party, path string, method func(*global.User, *model.ProductWorkLineLst) error) {

	RegisterOneProductWorkLineLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterDeleteOneProductWorkLineLst(party router.Party, path string, method func(*global.User, string, string) error) {

	RegisterIDOfProductWorkLineLst(party, "DELETE", path+"/{productId:string}/{workLineId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterSelectOneProductWorkLineLst(party router.Party, path string, method func(*global.User, string, string) (*model.ProductWorkLineLst, error)) {

	party.Get(path+"/{productId:string}/{workLineId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		productId := ctx.Params().GetString("productId")
		workLineId := ctx.Params().GetString("workLineId")
		result, err := method(user, productId, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterUpdateOneProductWorkLineLst(party router.Party, path string, method func(*global.User, *model.ProductWorkLineLst) error) {

	RegisterOneProductWorkLineLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterMultiProductWorkLineLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ProductWorkLineLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProductWorkLineLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterInsertProductWorkLineLst(party router.Party, path string, method func(*global.User, *[]model.ProductWorkLineLst) error) {

	RegisterMultiProductWorkLineLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterDeleteProductWorkLineLst(party router.Party, path string, method func(*global.User, *[]model.ProductWorkLineLst) error) {

	RegisterMultiProductWorkLineLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterSelectProductWorkLineLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ProductWorkLineLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProductWorkLineLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterQueryProductWorkLineLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-28 13:12:09
 *
 ******************************************************************************/
func RegisterUpdateProductWorkLineLst(party router.Party, path string, method func(*global.User, *[]model.ProductWorkLineLst) error) {

	RegisterMultiProductWorkLineLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSaveProductWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个保存ProductWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-10-28
 *
 ******************************************************************************/
func RegisterSaveProductWorkLineLst(party router.Party, path string, method func(*global.User, *model.ProductWorkLineData) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}

		var entity model.ProductWorkLineData
		if err := ctx.ReadJSON(&entity); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		err := method(user, &entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
