// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package me

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/me"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterOneShipableAUConfig(party router.Party, httpMethod string, path string, method func(*global.User, *model.ShipableAUConfig) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ShipableAUConfig)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterIDOfShipableAUConfig(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")

		err = method(user, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterInsertOneShipableAUConfig(party router.Party, path string, method func(*global.User, *model.ShipableAUConfig) error) {

	RegisterOneShipableAUConfig(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterDeleteOneShipableAUConfig(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfShipableAUConfig(party, "DELETE", path+"/{artId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterSelectOneShipableAUConfig(party router.Party, path string, method func(*global.User, string) (*model.ShipableAUConfig, error)) {

	party.Get(path+"/{artId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		result, err := method(user, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterUpdateOneShipableAUConfig(party router.Party, path string, method func(*global.User, *model.ShipableAUConfig) error) {

	RegisterOneShipableAUConfig(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterMultiShipableAUConfig(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ShipableAUConfig) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ShipableAUConfig, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterInsertShipableAUConfig(party router.Party, path string, method func(*global.User, *[]model.ShipableAUConfig) error) {

	RegisterMultiShipableAUConfig(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterDeleteShipableAUConfig(party router.Party, path string, method func(*global.User, *[]model.ShipableAUConfig) error) {

	RegisterMultiShipableAUConfig(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterSelectShipableAUConfig(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ShipableAUConfig, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipableAUConfig并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterQueryShipableAUConfig(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterUpdateShipableAUConfig(party router.Party, path string, method func(*global.User, *[]model.ShipableAUConfig) error) {

	RegisterMultiShipableAUConfig(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSaveShipableAUConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个保存单条ShipableAUConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2022-02-24 09:49:31
 *
 ******************************************************************************/
func RegisterSaveShipableAUConfig(party router.Party, path string, method func(user *global.User, entity *model.ShipableAUConfig) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			return
		}
		var data model.ShipableAUConfig
		if err := ctx.ReadJSON(&data); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, &data)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
