// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pln

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/pln"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterOneCustOrderQty(party router.Party, httpMethod string, path string, method func(*global.User, *model.CustOrderQty) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.CustOrderQty)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterIDOfCustOrderQty(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		custOrderId := ctx.Params().GetString("custOrderId")

		err = method(user, custOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterInsertOneCustOrderQty(party router.Party, path string, method func(*global.User, *model.CustOrderQty) error) {

	RegisterOneCustOrderQty(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterDeleteOneCustOrderQty(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfCustOrderQty(party, "DELETE", path+"/{custOrderId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterSelectOneCustOrderQty(party router.Party, path string, method func(*global.User, string) (*model.CustOrderQty, error)) {

	party.Get(path+"/{custOrderId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		custOrderId := ctx.Params().GetString("custOrderId")
		result, err := method(user, custOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterUpdateOneCustOrderQty(party router.Party, path string, method func(*global.User, *model.CustOrderQty) error) {

	RegisterOneCustOrderQty(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterMultiCustOrderQty(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.CustOrderQty) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.CustOrderQty, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterInsertCustOrderQty(party router.Party, path string, method func(*global.User, *[]model.CustOrderQty) error) {

	RegisterMultiCustOrderQty(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterDeleteCustOrderQty(party router.Party, path string, method func(*global.User, *[]model.CustOrderQty) error) {

	RegisterMultiCustOrderQty(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterSelectCustOrderQty(party router.Party, path string, method func(*global.User, map[string]string) ([]model.CustOrderQty, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CustOrderQty并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterQueryCustOrderQty(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateCustOrderQty
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条CustOrderQty的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-12-03 16:35:12
 *
 ******************************************************************************/
func RegisterUpdateCustOrderQty(party router.Party, path string, method func(*global.User, *[]model.CustOrderQty) error) {

	RegisterMultiCustOrderQty(party, "PUT", path, method)
}
