// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pln

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/pln"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterOneCustOrderStatus(party router.Party, httpMethod string, path string, method func(*global.User, *model.CustOrderStatus) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.CustOrderStatus)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterIDOfCustOrderStatus(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		custOrderId := ctx.Params().GetString("custOrderId")

		err = method(user, custOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterInsertOneCustOrderStatus(party router.Party, path string, method func(*global.User, *model.CustOrderStatus) error) {

	RegisterOneCustOrderStatus(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterDeleteOneCustOrderStatus(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfCustOrderStatus(party, "DELETE", path+"/{custOrderId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterSelectOneCustOrderStatus(party router.Party, path string, method func(*global.User, string) (*model.CustOrderStatus, error)) {

	party.Get(path+"/{custOrderId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		custOrderId := ctx.Params().GetString("custOrderId")
		result, err := method(user, custOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterUpdateOneCustOrderStatus(party router.Party, path string, method func(*global.User, *model.CustOrderStatus) error) {

	RegisterOneCustOrderStatus(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterMultiCustOrderStatus(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.CustOrderStatus) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.CustOrderStatus, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterInsertCustOrderStatus(party router.Party, path string, method func(*global.User, *[]model.CustOrderStatus) error) {

	RegisterMultiCustOrderStatus(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterDeleteCustOrderStatus(party router.Party, path string, method func(*global.User, *[]model.CustOrderStatus) error) {

	RegisterMultiCustOrderStatus(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterSelectCustOrderStatus(party router.Party, path string, method func(*global.User, map[string]string) ([]model.CustOrderStatus, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询CustOrderStatus并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterQueryCustOrderStatus(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateCustOrderStatus
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条CustOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 13:50:40
 *
 ******************************************************************************/
func RegisterUpdateCustOrderStatus(party router.Party, path string, method func(*global.User, *[]model.CustOrderStatus) error) {

	RegisterMultiCustOrderStatus(party, "PUT", path, method)
}
