// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pln

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/pln"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterOneHondaCalloffItemLst(party router.Party, httpMethod string, path string, method func(*global.User, *model.HondaCalloffItemLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.HondaCalloffItemLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterIDOfHondaCalloffItemLst(party router.Party, httpMethod string, path string, method func(*global.User, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		calloffId := ctx.Params().GetString("calloffId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, calloffId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterInsertOneHondaCalloffItemLst(party router.Party, path string, method func(*global.User, *model.HondaCalloffItemLst) error) {

	RegisterOneHondaCalloffItemLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterDeleteOneHondaCalloffItemLst(party router.Party, path string, method func(*global.User, string, int) error) {

	RegisterIDOfHondaCalloffItemLst(party, "DELETE", path+"/{calloffId:string}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterSelectOneHondaCalloffItemLst(party router.Party, path string, method func(*global.User, string, int) (*model.HondaCalloffItemLst, error)) {

	party.Get(path+"/{calloffId:string}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		calloffId := ctx.Params().GetString("calloffId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, calloffId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterUpdateOneHondaCalloffItemLst(party router.Party, path string, method func(*global.User, *model.HondaCalloffItemLst) error) {

	RegisterOneHondaCalloffItemLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterMultiHondaCalloffItemLst(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.HondaCalloffItemLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.HondaCalloffItemLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterInsertHondaCalloffItemLst(party router.Party, path string, method func(*global.User, *[]model.HondaCalloffItemLst) error) {

	RegisterMultiHondaCalloffItemLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterDeleteHondaCalloffItemLst(party router.Party, path string, method func(*global.User, *[]model.HondaCalloffItemLst) error) {

	RegisterMultiHondaCalloffItemLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterSelectHondaCalloffItemLst(party router.Party, path string, method func(*global.User, map[string]string) ([]model.HondaCalloffItemLst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询HondaCalloffItemLst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterQueryHondaCalloffItemLst(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateHondaCalloffItemLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条HondaCalloffItemLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-11-09 13:35:31
 *
 ******************************************************************************/
func RegisterUpdateHondaCalloffItemLst(party router.Party, path string, method func(*global.User, *[]model.HondaCalloffItemLst) error) {

	RegisterMultiHondaCalloffItemLst(party, "PUT", path, method)
}
