// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pln

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/pln"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterOneHondaDemand(party router.Party, httpMethod string, path string, method func(*global.User, *model.HondaDemand) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.HondaDemand)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterIDOfHondaDemand(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		demandId := ctx.Params().GetString("demandId")

		err = method(user, demandId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterInsertOneHondaDemand(party router.Party, path string, method func(*global.User, *model.HondaDemand) error) {

	RegisterOneHondaDemand(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterDeleteOneHondaDemand(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfHondaDemand(party, "DELETE", path+"/{demandId:string}", method)
}

func RegisterAnalysisHondaDemand(party router.Party, path string, method func(*global.User, string) error) {
	party.Handle("PUT", path+"/{demandId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		demandId := ctx.Params().GetString("demandId")

		err = method(user, demandId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterSelectOneHondaDemand(party router.Party, path string, method func(*global.User, string) (*model.HondaDemand, error)) {

	party.Get(path+"/{demandId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		demandId := ctx.Params().GetString("demandId")
		result, err := method(user, demandId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterUpdateOneHondaDemand(party router.Party, path string, method func(*global.User, *model.HondaDemand) error) {

	RegisterOneHondaDemand(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterMultiHondaDemand(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.HondaDemand) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.HondaDemand, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterInsertHondaDemand(party router.Party, path string, method func(*global.User, *[]model.HondaDemand) error) {

	RegisterMultiHondaDemand(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterDeleteHondaDemand(party router.Party, path string, method func(*global.User, *[]model.HondaDemand) error) {

	RegisterMultiHondaDemand(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterSelectHondaDemand(party router.Party, path string, method func(*global.User, map[string]string) ([]model.HondaDemand, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询HondaDemand并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterQueryHondaDemand(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateHondaDemand
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条HondaDemand的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-20 09:58:33
 *
 ******************************************************************************/
func RegisterUpdateHondaDemand(party router.Party, path string, method func(*global.User, *[]model.HondaDemand) error) {

	RegisterMultiHondaDemand(party, "PUT", path, method)
}
