// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pln

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/pln"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterOneReleaseTaskConfig(party router.Party, httpMethod string, path string, method func(*global.User, *model.ReleaseTaskConfig) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ReleaseTaskConfig)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterIDOfReleaseTaskConfig(party router.Party, httpMethod string, path string, method func(*global.User, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		configNr, err := ctx.Params().GetInt("configNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, configNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterInsertOneReleaseTaskConfig(party router.Party, path string, method func(*global.User, *model.ReleaseTaskConfig) error) {

	RegisterOneReleaseTaskConfig(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterDeleteOneReleaseTaskConfig(party router.Party, path string, method func(*global.User, int) error) {

	RegisterIDOfReleaseTaskConfig(party, "DELETE", path+"/{configNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterSelectOneReleaseTaskConfig(party router.Party, path string, method func(*global.User, int) (*model.ReleaseTaskConfig, error)) {

	party.Get(path+"/{configNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		configNr, err := ctx.Params().GetInt("configNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, configNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterUpdateOneReleaseTaskConfig(party router.Party, path string, method func(*global.User, *model.ReleaseTaskConfig) error) {

	RegisterOneReleaseTaskConfig(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterMultiReleaseTaskConfig(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ReleaseTaskConfig) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ReleaseTaskConfig, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterInsertReleaseTaskConfig(party router.Party, path string, method func(*global.User, *[]model.ReleaseTaskConfig) error) {

	RegisterMultiReleaseTaskConfig(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterDeleteReleaseTaskConfig(party router.Party, path string, method func(*global.User, *[]model.ReleaseTaskConfig) error) {

	RegisterMultiReleaseTaskConfig(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterSelectReleaseTaskConfig(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ReleaseTaskConfig, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ReleaseTaskConfig并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterQueryReleaseTaskConfig(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateReleaseTaskConfig
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ReleaseTaskConfig的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-06-23 17:08:07
 *
 ******************************************************************************/
func RegisterUpdateReleaseTaskConfig(party router.Party, path string, method func(*global.User, *[]model.ReleaseTaskConfig) error) {

	RegisterMultiReleaseTaskConfig(party, "PUT", path, method)
}

func RegisterSaveReleaseTaskConfig(party router.Party, path string, method func(user *global.User, entity *model.ReleaseTaskConfig) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var data model.ReleaseTaskConfig
		if err := ctx.ReadJSON(&data); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, &data)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

func RegisterSelectConfig(party router.Party, path string, method func(user *global.User, objType, objId string) (*model.ReleaseTaskConfig, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		objType := ctx.URLParam("businessObjType")
		objId := ctx.URLParam("businessObjId")
		result, err := method(user, objType, objId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}
