// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pln

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/pln"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterOneToyotaTask(party router.Party, httpMethod string, path string, method func(*global.User, *model.ToyotaTask) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ToyotaTask)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterIDOfToyotaTask(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		taskId := ctx.Params().GetString("taskId")

		err = method(user, taskId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterInsertOneToyotaTask(party router.Party, path string, method func(*global.User, *model.ToyotaTask) error) {

	RegisterOneToyotaTask(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterDeleteOneToyotaTask(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfToyotaTask(party, "DELETE", path+"/{taskId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterSelectOneToyotaTask(party router.Party, path string, method func(*global.User, string) (*model.ToyotaTask, error)) {

	party.Get(path+"/{taskId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		taskId := ctx.Params().GetString("taskId")
		result, err := method(user, taskId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterUpdateOneToyotaTask(party router.Party, path string, method func(*global.User, *model.ToyotaTask) error) {

	RegisterOneToyotaTask(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterMultiToyotaTask(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.ToyotaTask) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ToyotaTask, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterInsertToyotaTask(party router.Party, path string, method func(*global.User, *[]model.ToyotaTask) error) {

	RegisterMultiToyotaTask(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterDeleteToyotaTask(party router.Party, path string, method func(*global.User, *[]model.ToyotaTask) error) {

	RegisterMultiToyotaTask(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterSelectToyotaTask(party router.Party, path string, method func(*global.User, map[string]string) ([]model.ToyotaTask, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ToyotaTask并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterQueryToyotaTask(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateToyotaTask
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ToyotaTask的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-07-12 13:58:15
 *
 ******************************************************************************/
func RegisterUpdateToyotaTask(party router.Party, path string, method func(*global.User, *[]model.ToyotaTask) error) {

	RegisterMultiToyotaTask(party, "PUT", path, method)
}
